@@ -20,16 +20,6 @@ struct calendar {
 	uint8_t  weekday;	/* 0..7, 0=Sunday */
 };
 
-/* ISO week calendar date */
-struct isodate {
-	uint16_t year;		/* year (A.D.) */
-	uint8_t	 week;		/* 1..53, week in year */
-	uint8_t	 weekday;	/* 1..7, 1=Monday */
-	uint8_t	 hour;		/* hour of day, midnight = 0 */
-	uint8_t	 minute;	/* minute of hour */
-	uint8_t	 second;	/* second of minute */
-};
-
 /* general split representation */
 typedef struct {
 	int32_t hi;
@@ -62,19 +52,11 @@ extern systime_func_ptr ntpcal_set_timefunc(systime_func_ptr);
 #define	SECSPERWEEK	(DAYSPERWEEK * SECSPERDAY)
 #define	SECSPERYEAR	(365 * SECSPERDAY)	/* regular year */
 #define	SECSPERLEAPYEAR	(366 * SECSPERDAY)	/* leap year */
-#define	SECSPERAVGYEAR	31556952		/* mean year length over 400yrs */
+#define	SECSPERAVGYEAR	31556952	/* mean year length over 400yrs */
 
 /*
- * Convert between 'time_t' and 'time64_t'
- */
-extern time64_t time_to_time64(const time_t);
-extern time_t time64_to_time(const time64_t);
-
-/*
- * Get the build date & time. ATTENTION: The time zone is not specified!
- * This depends entirely on the C compilers' capabilities to properly
- * expand the '__TIME__' and '__DATE__' macros, as required by the C
- * standard.
+ * Get the build date & time in UTC.  This depends on the BUILD_EPOCH
+ * which is fixed at configure time.
  */
 extern int
 ntpcal_get_build_date(struct calendar * /* jd */);
@@ -108,26 +90,15 @@ ntpcal_daysplit(const time64_t);
  * expressed in 64 bits to avoid overflow.
  */
 extern time64_t
-ntpcal_dayjoin(int32_t /* days */, int32_t /* seconds */);
+ntpcal_dayjoin(int32_t /* days */, int32_t /* seconds */) __attribute__((const));
 
 /*
  * Convert elapsed years in Era into elapsed days in Era.
  */
 extern int32_t
-ntpcal_days_in_years(int32_t /* years */);
+ntpcal_days_in_years(int32_t /* years */) __attribute__((const));
 
-/*
- * Convert a number of elapsed month in a year into elapsed days
- * in year.
- *
- * The month will be normalized, and 'res.hi' will contain the
- * excessive years that must be considered when converting the years,
- * while 'res.lo' will contain the days since start of the
- * year. (Expect the resulting days to be negative, with a positive
- * excess! But then, we need no leap year flag, either...)
- */
-extern ntpcal_split
-ntpcal_days_in_months(int32_t /* months */);
+#define days_per_year(x)	((x) % 4 ? 365 : ((x % 400) ? ((x % 100) ? 366 : 365) : 366))
 
 /*
  * Convert ELAPSED years/months/days of gregorian calendar to elapsed
@@ -140,17 +111,8 @@ ntpcal_edate_to_eradays(int32_t /* years */, int32_t /* months */, int32_t /* md
  * Convert a time spec to seconds. No range checks done here!
  */
 extern int32_t
-ntpcal_etime_to_seconds(int32_t /* hours */, int32_t /* minutes */, int32_t /* seconds */);
-
-/*
- * Convert ELAPSED years/months/days of gregorian calendar to elapsed
- * days in year.
- *
- * Note: This will give the true difference to the start of the given year,
- * even if months & days are off-scale.
- */
-extern int32_t
-ntpcal_edate_to_yeardays(int32_t /* years */, int32_t /* months */, int32_t /* mdays */);
+ntpcal_etime_to_seconds(int32_t /* hours */, int32_t /* minutes */,
+                        int32_t /* seconds */) __attribute__((const));
 
 /*
  * Convert the date part of a 'struct tm' (that is, year, month,
@@ -194,18 +156,11 @@ ntpcal_split_yeardays(int32_t /* eyd */, bool /* isleapyear */);
 extern int
 ntpcal_rd_to_date(struct calendar * /* jt */, int32_t /* rd */);
 
-/*
- * Convert a RataDie number into the date part of a 'struct
- * tm'. Return false if the year is regular year, true if the year is a leap
- * year.
- */
-extern bool
-ntpcal_rd_to_tm(struct tm * /* utm */, int32_t /* rd */);
-
 /*
  * Take a value of seconds since midnight and split it into hhmmss in
  * a 'struct calendar'. Return excessive days.
  */
+/* used by ntpd/refclock_nmea.c */
 extern int32_t
 ntpcal_daysec_to_date(struct calendar * /* jt */, int32_t /* secs */);
 
@@ -213,53 +168,19 @@ ntpcal_daysec_to_date(struct calendar * /* jt */, int32_t /* secs */);
  * Take the time part of a 'struct calendar' and return the seconds
  * since midnight.
  */
+/* used by ntpd/refclock_nmea.c */
 extern int32_t
 ntpcal_date_to_daysec(const struct calendar *);
 
-/*
- * Take a value of seconds since midnight and split it into hhmmss in
- * a 'struct tm'. Return excessive days.
- */
-extern int32_t
-ntpcal_daysec_to_tm(struct tm * /* utm */, int32_t /* secs */);
-
 extern int32_t
 ntpcal_tm_to_daysec(const struct tm * /* utm */);
 
-/*
- * convert a year number to rata die of year start
- */
-extern int32_t
-ntpcal_year_to_ystart(int32_t /* year */);
-
-/*
- * For a given RataDie, get the RataDie of the associated year start,
- * that is, the RataDie of the last January,1st on or before that day.
- */
-extern int32_t
-ntpcal_rd_to_ystart(int32_t /* rd */);
-
-/*
- * convert a RataDie to the RataDie of start of the calendar month.
- */
-extern int32_t
-ntpcal_rd_to_mstart(int32_t /* year */);
-
-
-extern int
-ntpcal_daysplit_to_date(struct calendar * /* jt */,
-			const ntpcal_split * /* ds */, int32_t /* dof */);
-
-extern int
-ntpcal_daysplit_to_tm(struct tm * /* utm */, const ntpcal_split * /* ds */,
-		      int32_t /* dof */);
-
 extern int
 ntpcal_time_to_date(struct calendar * /* jd */, const time64_t /* ts */);
 
 extern int32_t
 ntpcal_periodic_extend(int32_t /* pivot */, int32_t /* value */,
-		       int32_t /* cycle */);
+		       int32_t /* cycle */) __attribute__((const));
 
 extern int
 ntpcal_ntp64_to_date(struct calendar * /* jd */, const time64_t /* ntp */);
@@ -268,59 +189,9 @@ extern int
 ntpcal_ntp_to_date(struct calendar * /* jd */,	uint32_t /* ntp */,
 		   const time_t * /* pivot */);
 
-extern time64_t
-ntpcal_date_to_ntp64(const struct calendar * /* jd */);
-
-extern uint32_t
-ntpcal_date_to_ntp(const struct calendar * /* jd */);
-
 extern time_t
 ntpcal_date_to_time(const struct calendar * /* jd */);
 
-/*
- * ISO week-calendar conversions
- */
-extern int32_t
-isocal_weeks_in_years(int32_t  /* years */);
-
-extern ntpcal_split
-isocal_split_eraweeks(int32_t /* weeks */);
-
-extern int
-isocal_ntp64_to_date(struct isodate * /* id */, const time64_t /* ntp */);
-
-extern int
-isocal_ntp_to_date(struct isodate * /* id */, uint32_t /* ntp */,
-		   const time_t * /* pivot */);
-
-extern time64_t
-isocal_date_to_ntp64(const struct isodate * /* id */);
-
-extern uint32_t
-isocal_date_to_ntp(const struct isodate * /* id */);
-
-
-/*
- * day-of-week calculations
- *
- * Given a RataDie and a day-of-week, calculate a RDN that is reater-than,
- * greater-or equal, closest, less-or-equal or less-than the given RDN
- * and denotes the given day-of-week
- */
-extern int32_t
-ntpcal_weekday_gt(int32_t  /* rdn */, int32_t /* dow */);
-
-extern int32_t
-ntpcal_weekday_ge(int32_t /* rdn */, int32_t /* dow */);
-
-extern int32_t
-ntpcal_weekday_close(int32_t /* rdn */, int32_t  /* dow */);
-
-extern int32_t
-ntpcal_weekday_le(int32_t /* rdn */, int32_t /* dow */);
-
-extern int32_t
-ntpcal_weekday_lt(int32_t /* rdn */, int32_t /* dow */);
 
 /*
  * Additional support stuff for Ed Rheingold's calendrical calculations
@@ -374,6 +245,6 @@ ntpcal_weekday_lt(int32_t /* rdn */, int32_t /* dow */);
  * 2208988800.  This is larger than 32-bit INT_MAX, so unsigned
  * type is forced.
  */
-#define	JAN_1970 ((u_int)NTP_TO_UNIX_DAYS * (u_int)SECSPERDAY)
+#define	JAN_1970 ((unsigned int)NTP_TO_UNIX_DAYS * (unsigned int)SECSPERDAY)
 
 #endif
