@@ -20,6 +20,7 @@
 #ifndef CONFIG_FILE
 #  define	CONFIG_FILE "/etc/ntp.conf"
 #endif /* not CONFIG_FILE */
+#define CONFIG_DIR	"ntp.d"
 
 /* Limits */
 #define MAXLINE 1024
@@ -32,7 +33,6 @@
 /* list of servers from command line for config_peers() */
 extern	int	cmdline_server_count;
 extern	char **	cmdline_servers;
-extern	bool	force_synchronous_dns;
 
 typedef struct int_range_tag {
 	int	first;
@@ -47,7 +47,7 @@ struct attr_val_tag {
 	int		type;	/* T_String, T_Integer, ... */
 	union val {
 		int		i;
-		u_int		u;
+		unsigned int	u;
 		int_range	r;
 		double		d;
 		char *		s;
@@ -61,7 +61,7 @@ typedef struct address_node_tag address_node;
 struct address_node_tag {
 	address_node *	link;
 	char *		address;
-	u_short		type;	/* family, AF_UNSPEC (0), AF_INET[6] */
+	unsigned short	type;	/* family, AF_UNSPEC (0), AF_INET[6] */
 };
 
 typedef DECL_FIFO_ANCHOR(address_node) address_fifo;
@@ -85,6 +85,7 @@ typedef DECL_FIFO_ANCHOR(string_node) string_fifo;
 typedef struct restrict_node_tag restrict_node;
 struct restrict_node_tag {
 	restrict_node *	link;
+	int		mode;	/* restrict or unrestrict? */
 	address_node *	addr;
 	address_node *	mask;
 	int_fifo *	flags;
@@ -93,22 +94,6 @@ struct restrict_node_tag {
 
 typedef DECL_FIFO_ANCHOR(restrict_node) restrict_fifo;
 
-/*
- * Read-only control knobs for a peer structure.
- * Packaging these makes context copies a bit more succinct.
- */
-struct peer_ctl {
-	uint8_t		version;
-	int		flags;
-	uint8_t		minpoll;
-	uint8_t		maxpoll;
-	uint32_t	ttl;
-	keyid_t		peerkey;
-	uint32_t	baud;
-	char		*path;
-	char		*ppspath;
-};
-
 typedef struct peer_node_tag peer_node;
 struct peer_node_tag {
 	peer_node *	link;
@@ -261,13 +246,13 @@ address_node *create_address_node(char *addr, int type);
 void destroy_address_node(address_node *my_node);
 attr_val *create_attr_dval(int attr, double value);
 attr_val *create_attr_ival(int attr, int value);
-attr_val *create_attr_uval(int attr, u_int value);
+attr_val *create_attr_uval(int attr, unsigned int value);
 attr_val *create_attr_rangeval(int attr, int first, int last);
 attr_val *create_attr_sval(int attr, const char *s);
 filegen_node *create_filegen_node(int filegen_token,
 				  attr_val_fifo *options);
 string_node *create_string_node(char *str);
-restrict_node *create_restrict_node(address_node *addr,
+restrict_node *create_restrict_node(int mode, address_node *addr,
 				    address_node *mask,
 				    int_fifo *flags, int line_no);
 int_node *create_int_node(int val);
