@@ -7,6 +7,7 @@
 #include <sys/types.h>
 #include <sys/socket.h>
 #include <string.h>
+#include <signal.h>
 #include <errno.h>
 #include <stdarg.h>
 
@@ -29,24 +30,16 @@
 extern const char *ntpd_version(void);
 
 extern	int	mprintf(const char *, ...) NTP_PRINTF(1, 2);
-extern	int	mfprintf(FILE *, const char *, ...) NTP_PRINTF(2, 3);
-extern	int	mvfprintf(FILE *, const char *, va_list) NTP_PRINTF(2, 0);
 extern	int	mvsnprintf(char *, size_t, const char *, va_list)
 			NTP_PRINTF(3, 0);
-extern	int	msnprintf(char *, size_t, const char *, ...)
-			NTP_PRINTF(3, 4);
 extern	void	msyslog(int, const char *, ...) NTP_PRINTF(2, 3);
 extern	void	init_logging	(const char *, uint32_t, int);
 extern	int	change_logfile	(const char *, int);
 extern	void	reopen_logfile  (void);
 extern	void	setup_logfile	(const char *);
-extern	void	errno_to_str(int, char *, size_t);
-
-typedef void (*ctrl_c_fn)(void);
 
 /* authkeys.c */
 extern	void	auth_delkeys	(void);
-extern	int	auth_havekey	(keyid_t);
 extern	int	authdecrypt	(keyid_t, uint32_t *, int, int);
 extern	int	authencrypt	(keyid_t, uint32_t *, int);
 extern	int	authhavekey	(keyid_t);
@@ -55,13 +48,9 @@ extern	bool	authreadkeys	(const char *);
 extern	void	authtrust	(keyid_t, bool);
 extern	bool	authusekey	(keyid_t, int, const uint8_t *);
 
-extern	const char *clockname	(int);
-extern	int	clocktime	(int, int, int, int, int, uint32_t, uint32_t *, uint32_t *);
+extern	int	clocktime	(int, int, int, int, int, int, uint32_t, uint32_t *, uint32_t *);
 extern	void	init_auth	(void);
-extern	void	init_lib	(void);
 extern	void	init_network	(void);
-extern	struct savekey *auth_findkey (keyid_t);
-extern	void	auth_moremem	(int);
 extern	void	auth_prealloc_symkeys(int);
 extern	int	ymd2yd		(int, int, int);
 
@@ -79,7 +68,7 @@ int ntp_getopt_long(int argc, char* const argv[], const char *optstring,
 		    const struct option *longopts, int *longindex);
 
 /* a_md5encrypt.c */
-extern	int	mac_authdecrypt	(int, uint8_t *, uint32_t *, int, int);
+extern	bool	mac_authdecrypt	(int, uint8_t *, uint32_t *, int, int);
 extern	int	mac_authencrypt	(int, uint8_t *, uint32_t *, int);
 extern	void	mac_setkey	(keyid_t, int, const uint8_t *, size_t);
 extern	uint32_t	addr2refid	(sockaddr_u *);
@@ -130,23 +119,19 @@ extern	const char * res_access_flags(unsigned short);
 extern	const char * k_st_flags	(uint32_t);
 #endif
 extern	char *	statustoa	(int, int);
-extern	sockaddr_u * netof	(sockaddr_u *);
+extern	sockaddr_u * netof6	(sockaddr_u *);
 extern	char *	numtoa		(uint32_t);
 extern	const char * socktoa	(const sockaddr_u *);
 extern	const char * sockporttoa(const sockaddr_u *);
-extern	unsigned short	sock_hash	(const sockaddr_u *);
-extern	int	sockaddr_masktoprefixlen(const sockaddr_u *);
-extern	bool	octtoint	(const char *, unsigned long *);
-extern	unsigned long	ranp2		(int);
+extern	unsigned short	sock_hash(const sockaddr_u *) __attribute__((pure));
 extern	const char *refid_str	(uint32_t, int);
 
-extern	bool	decodenetnum	(const char *, sockaddr_u *);
+extern	int	decodenetnum	(const char *, sockaddr_u *);
 
 extern	void	signal_no_reset (int, void (*func)(int));
-extern	void	set_ctrl_c_hook (ctrl_c_fn);
+extern void signal_no_reset1(int, void (*func)(int, siginfo_t *, void *));
 
 extern	void	getauthkeys 	(const char *);
-extern	void	rereadkeys	(void);
 
 /*
  * Variable declarations for libntp.
@@ -179,13 +164,8 @@ extern int	ntp_optind;		/* global argv index */
 extern bool	ipv4_works;
 extern bool	ipv6_works;
 
-/* machines.c */
-typedef void (*pset_tod_using)(const char *);
-extern pset_tod_using	set_tod_using;
-
 /* ssl_init.c */
 extern	void	ssl_init		(void);
-extern	int	keytype_from_text	(const char *);
 
 /* strl-obsd.c */
 #ifndef HAVE_STRLCPY		/* + */
@@ -220,6 +200,9 @@ extern bool	trunc_os_clock;		/* sys_tick > measured_tick */
 #define COMPARE_EQUAL		0
 #define COMPARE_LESSTHAN	-1
 
+/* hack to ignore GCC Unused Result */
+#define IGNORE(r) do{if(r){}}while(0)
+
 extern bool sandbox(const bool droproot, char *user, const char *group,
 	     const char *chrootdir, bool want_dynamic_interface_tracking);
 
