@@ -5,7 +5,6 @@
 #include <stdio.h>
 #include <ctype.h>
 
-#include "ntp_fp.h"
 #include "ntp.h"
 #include "ntp_syslog.h"
 #include "ntp_stdlib.h"
@@ -25,7 +24,7 @@ nexttok(
 	char	**str
 	)
 {
-	register char *cp;
+	char *cp;
 	char *starttok;
 
 	cp = *str;
@@ -85,12 +84,12 @@ authreadkeys(
 	 */
 	fp = fopen(file, "r");
 	if (fp == NULL) {
-		msyslog(LOG_ERR, "authreadkeys: file %s: %m",
+		msyslog(LOG_ERR, "AUTH: authreadkeys: file %s: %m",
 		    file);
 		return false;
 	}
 	ssl_init();
-msyslog(LOG_ERR, "authreadkeys: reading %s", file);
+msyslog(LOG_ERR, "AUTH: authreadkeys: reading %s", file);
 
 	/*
 	 * Remove all existing keys
@@ -108,16 +107,16 @@ msyslog(LOG_ERR, "authreadkeys: reading %s", file);
 		/*
 		 * First is key number.  See if it is okay.
 		 */
-		keyno = atoi(token);
+		keyno = (keyid_t)atoi(token);
 		if (keyno == 0) {
 			msyslog(LOG_ERR,
-			    "authreadkeys: cannot change key %s", token);
+			    "AUTH: authreadkeys: cannot change key %s", token);
 			continue;
 		}
 
 		if (keyno > NTP_MAXKEY) {
 			msyslog(LOG_ERR,
-			    "authreadkeys: key %s > %d reserved",
+			    "AUTH: authreadkeys: key %s > %d reserved",
 			    token, NTP_MAXKEY);
 			continue;
 		}
@@ -128,7 +127,7 @@ msyslog(LOG_ERR, "authreadkeys: reading %s", file);
 		token = nexttok(&line);
 		if (token == NULL) {
 			msyslog(LOG_ERR,
-			    "authreadkeys: no key type for key %d", keyno);
+			    "AUTH: authreadkeys: no key type for key %u", keyno);
 			continue;
 		}
 		/*
@@ -144,7 +143,7 @@ msyslog(LOG_ERR, "authreadkeys: reading %s", file);
 		 */
 		char *upcased;
 		char *pch;
-		LIB_GETBUF(upcased);
+		upcased = lib_getbuf();
 		strlcpy(upcased, token, LIB_BUFLENGTH);
 		for (pch = upcased; '\0' != *pch; pch++)
 			*pch = (char)toupper((unsigned char)*pch);
@@ -154,12 +153,12 @@ msyslog(LOG_ERR, "authreadkeys: reading %s", file);
 			keytype = NID_md5;
 		if (keytype == 0) {
 			msyslog(LOG_ERR,
-			    "authreadkeys: invalid type for key %d", keyno);
+			    "AUTH: authreadkeys: invalid type for key %u", keyno);
 			continue;
 		}
 		if (EVP_get_digestbynid(keytype) == NULL) {
 			msyslog(LOG_ERR,
-			    "authreadkeys: no algorithm for key %d", keyno);
+			    "AUTH: authreadkeys: no algorithm for key %u", keyno);
 			continue;
 		}
 
@@ -172,7 +171,7 @@ msyslog(LOG_ERR, "authreadkeys: reading %s", file);
 		token = nexttok(&line);
 		if (token == NULL) {
 			msyslog(LOG_ERR,
-			    "authreadkeys: no key for key %d", keyno);
+			    "AUTH: authreadkeys: no key for key %u", keyno);
 			continue;
 		}
 		len = strlen(token);
@@ -194,18 +193,19 @@ msyslog(LOG_ERR, "authreadkeys: reading %s", file);
 				if (j & 1)
 					keystr[j / 2] |= temp;
 				else
-					keystr[j / 2] = temp << 4;
+					keystr[j / 2] = (uint8_t)(temp << 4);
 			}
 			if (j < jlim) {
-				msyslog(LOG_ERR,
-					"authreadkeys: invalid hex digit for key %d", keyno);
-				continue;
+			    msyslog(LOG_ERR,
+				"AUTH: authreadkeys: invalid hex digit for key %u",
+				keyno);
+			    continue;
 			}
 			mac_setkey(keyno, keytype, keystr, jlim / 2);
 			keys++;
 		}
 	}
 	fclose(fp);
-msyslog(LOG_ERR, "authreadkeys: added %d keys", keys);
+	msyslog(LOG_ERR, "AUTH: authreadkeys: added %d keys", keys);
 	return true;
 }
