@@ -31,9 +31,13 @@ static int32_t   ntp_to_year(uint32_t);
 static uint32_t year_to_ntp(int32_t);
 
 /*
- * Take a time spec given as day-of-year, hour, minute and second as
+ * Take a time spec given as year, day-of-year, hour, minute and second as
  * well as a GMT offset in hours and convert it to a NTP time stamp in
- * '*ts_ui'. The value will be in the range (rec_ui-0.5yrs) to
+ * '*ts_ui'.  There are two cases: ether the year is > 99, in which
+ * case it is used, or it is < 99 in which case we ignore it and try
+ * to deduce a year,
+ *
+ * The value will be in the range (rec_ui-0.5yrs) to
  * (rec_ui+0.5yrs). A hint for the current start-of-year will be
  * read from '*yearstart'.
  *
@@ -49,13 +53,14 @@ static uint32_t year_to_ntp(int32_t);
  */
 int
 clocktime(
+	int	year	 ,	/* year */
 	int	yday	 ,	/* day-of-year */
 	int	hour	 ,	/* hour of day */
 	int	minute	 ,	/* minute of hour */
 	int	second	 ,	/* second of minute */
 	int	tzoff	 ,	/* hours west of GMT */
 	uint32_t rec_ui	 ,	/* pivot value */
-	uint32_t *yearstart,	/* cached start-of-year */
+	uint32_t *yearstart,	/* cached start-of-year, secs from NTP epoch */
 	uint32_t *ts_ui	 )	/* effective time stamp */
 {
 	uint32_t ystt[3];	/* year start */
@@ -72,6 +77,27 @@ clocktime(
 			     MINSPERHR * ((int32_t)hour + (int32_t)tzoff +
 					  HRSPERDAY * ((int32_t)yday - 1))));
 	/*
+	 * Year > 1970 - from a 4-digit year stamp, must be greater
+	 * than POSIX epoch. Means we're not dependent on the pivot
+	 * value (derived from the packet receipt timestamp, and thus
+	 * ultimately from the system clock) to be correct. CLOSETIME
+	 * clipping to the receive time will *not* be applied in this
+	 * case. These two lines thus make it possible to recover from
+	 * a trashed or zeroed system clock.
+	 *
+	 * Warning: the hack in the NMEA driver that rectifies 4-digit
+	 * years from 2-digit ones has an expiration date in 2399.
+	 * After that this code will go badly wrong.
+	 */
+	if (year > 1970) {
+	    *yearstart = year_to_ntp(year);
+	    *ts_ui = *yearstart + tmp;
+	    return true;
+	}
+
+        /*
+	 * Year was too small to make sense, probably from a 2-digit
+	 * year stamp.
 	 * Based on the cached year start, do a first attempt. Be
 	 * happy and return if this gets us better than NEARTIME to
 	 * the receive time stamp. Do this only if the cached year
@@ -80,7 +106,7 @@ clocktime(
 	 */
 	if (*yearstart) {
 		/* -- get time stamp of potential solution */
-		test[0] = (uint32_t)(*yearstart) + tmp;
+		test[0] = (uint32_t)(*yearstart) + (unsigned int)tmp;
 		/* -- calc absolute difference to receive time */
 		diff[0] = test[0] - rec_ui;
 		if (diff[0] >= 0x80000000u)
@@ -102,12 +128,12 @@ clocktime(
 	 * around the guess and select the entry with the minimum
 	 * absolute difference to the receive time stamp.
 	 */
-	y = ntp_to_year(rec_ui - tmp);
+	y = ntp_to_year(rec_ui - (unsigned int)tmp);
 	for (idx = 0; idx < 3; idx++) {
 		/* -- get year start of potential solution */
 		ystt[idx] = year_to_ntp(y + idx - 1);
 		/* -- get time stamp of potential solution */
-		test[idx] = ystt[idx] + tmp;
+		test[idx] = ystt[idx] + (unsigned int)tmp;
 		/* -- calc absolute difference to receive time */
 		diff[idx] = test[idx] - rec_ui;
 		if (diff[idx] >= 0x80000000u)
@@ -143,6 +169,6 @@ year_to_ntp(
 	int32_t year)
 {
 	uint32_t days;
-	days = ntpcal_days_in_years(year-1) - DAY_NTP_STARTS + 1;
+	days = (uint32_t)ntpcal_days_in_years(year-1) - DAY_NTP_STARTS + 1;
 	return days * SECSPERDAY;
 }
