@@ -6,15 +6,13 @@
  */
 
 #include "config.h"
+#include "ntp_stdlib.h"
 
-#include <unistd.h>
-#include <ctype.h>
-#include "ntp.h"
-
+#include <stdbool.h>
 #include <openssl/evp.h>
 
 #if OPENSSL_VERSION_NUMBER < 0x10100000L || defined(LIBRESSL_VERSION_NUMBER)
-void	atexit_ssl_cleanup(void);
+static void	atexit_ssl_cleanup(void);
 #endif
 
 static bool ssl_init_done;
@@ -25,8 +23,6 @@ ssl_init(void)
 	if (ssl_init_done)
 		return;
 
-	init_lib();
-
 #if OPENSSL_VERSION_NUMBER < 0x10100000L || defined(LIBRESSL_VERSION_NUMBER)
 	OpenSSL_add_all_digests();
 	atexit(&atexit_ssl_cleanup);
@@ -37,7 +33,7 @@ ssl_init(void)
 
 
 #if OPENSSL_VERSION_NUMBER < 0x10100000L || defined(LIBRESSL_VERSION_NUMBER)
-void
+static void
 atexit_ssl_cleanup(void)
 {
 	if (!ssl_init_done)
