@@ -9,7 +9,6 @@
 #include "ntp.h"
 #include "ntp_syslog.h"
 #include "ntp_stdlib.h"
-#include "ntp_random.h"
 #include "timespecops.h"
 #include "ntp_calendar.h"
 
@@ -66,8 +65,8 @@ double	sys_fuzz = 0;		/* min. time to read the clock (s) */
 bool	trunc_os_clock;		/* sys_tick > measured_tick */
 time_stepped_callback	step_callback;
 
-static double	sys_residual = 0;	/* adjustment residue (s) */
-static long	sys_fuzz_nsec = 0;	/* min. time to read the clock (ns) */
+static doubletime_t  sys_residual = 0;	/* adjustment residue (s) */
+static long          sys_fuzz_nsec = 0;	/* minimum time to read clock (ns) */
 
 /* perlinger@ntp.org: As 'get_systime()' does its own check for clock
  * backstepping, this could probably become a local variable in
@@ -76,6 +75,8 @@ static long	sys_fuzz_nsec = 0;	/* min. time to read the clock (ns) */
  */
 static bool lamport_violated;	/* clock was stepped back */
 
+static  void	get_ostime	(struct timespec *tsp);
+
 void
 set_sys_fuzz(
 	double	fuzz_val
@@ -88,7 +89,7 @@ set_sys_fuzz(
 }
 
 
-void
+static void
 get_ostime(
 	struct timespec *	tsp
 	)
@@ -99,7 +100,7 @@ get_ostime(
 	rc = clock_gettime(CLOCK_REALTIME, tsp);
 	if (rc < 0) {
 #ifndef __COVERITY__
-		msyslog(LOG_ERR, "read system clock failed: %m (%d)",
+		msyslog(LOG_ERR, "TIME: read system clock failed: %m (%d)",
 			errno);
 #endif /* __COVERITY__ */
 		exit(1);
@@ -117,7 +118,7 @@ static	void	normalize_time	(struct timespec, long, l_fp *);
 static void
 normalize_time(
 	struct timespec ts,		/* seconds and nanoseconds */
-	long rand,
+	long randd,
 	l_fp *now		/* system time */
 	)
 {
@@ -158,7 +159,7 @@ normalize_time(
 		ts_lam = sub_tspec(ts_min, ts);
 		if (ts_lam.tv_sec > 0 && !lamport_violated) {
 		    msyslog(LOG_ERR,
-			"get_systime Lamport advance exceeds one second (%.9f)",
+			"CLOCK: get_systime Lamport advance exceeds one second (%.9f)",
 			ts_lam.tv_sec + S_PER_NS * ts_lam.tv_nsec);
 		    exit(1);
 		}
@@ -174,7 +175,7 @@ normalize_time(
 	/*
 	 * Add in the fuzz.
 	 */
-	dfuzz = rand * 2. / FRAC * sys_fuzz;
+	dfuzz = randd * 2. / FRAC * sys_fuzz;
 	lfpfuzz = dtolfp(dfuzz);
 	result += lfpfuzz;
 
@@ -186,19 +187,19 @@ normalize_time(
 	if (lfp_prev != 0 && !lamport_violated) {
 		if (!L_ISGTU(result, lfp_prev) &&
 		    sys_fuzz > 0.) {
-			msyslog(LOG_ERR, "ts_prev %s ts_min %s",
+			msyslog(LOG_ERR, "CLOCK: ts_prev %s ts_min %s",
 				tspectoa(ts_prev_log),
 				tspectoa(ts_min));
-			msyslog(LOG_ERR, "ts %s", tspectoa(ts));
-			msyslog(LOG_ERR, "sys_fuzz %ld nsec, prior fuzz %.9f",
+			msyslog(LOG_ERR, "CLOCK: ts %s", tspectoa(ts));
+			msyslog(LOG_ERR, "CLOCK: sys_fuzz %ld nsec, prior fuzz %.9f",
 				sys_fuzz_nsec, dfuzz_prev);
-			msyslog(LOG_ERR, "this fuzz %.9f",
+			msyslog(LOG_ERR, "CLOCK: this fuzz %.9f",
 				dfuzz);
 			lfpdelta = lfp_prev;
 			lfpdelta -= result;
 			ddelta = lfptod(lfpdelta);
 			msyslog(LOG_ERR,
-				"prev get_systime 0x%x.%08x is %.9f later than 0x%x.%08x",
+				"CLOCK: prev get_systime 0x%x.%08x is %.9f later than 0x%x.%08x",
 				lfpuint(lfp_prev), lfpfrac(lfp_prev),
 				ddelta, lfpuint(result), lfpfrac(result));
 		}
@@ -235,7 +236,7 @@ adj_systime(
 	struct timeval adjtv;	/* new adjustment */
 	struct timeval oadjtv;	/* residual adjustment */
 	double	quant;		/* quantize to multiples of */
-	double	dtemp;
+	doubletime_t	dtemp;
 	long	ticks;
 	bool	isneg = false;
 
@@ -251,7 +252,7 @@ adj_systime(
 	 * EVNT_NSET adjtime() can be aborted by a tiny adjtime()
 	 * triggered by sys_residual.
 	 */
-	if (0. == now)
+	if ( D_ISZERO_NS(now))
 		return true;
 
 	/*
@@ -297,7 +298,7 @@ adj_systime(
 	}
 	if (adjtv.tv_sec != 0 || adjtv.tv_usec != 0) {
 		if (ladjtime(&adjtv, &oadjtv) < 0) {
-			msyslog(LOG_ERR, "adj_systime: %m");
+			msyslog(LOG_ERR, "CLOCK: adj_systime: %m");
 			return false;
 		}
 	}
@@ -314,33 +315,86 @@ adj_systime(
 
 bool
 step_systime(
-	double step,
+	doubletime_t step,
 	int (*settime)(struct timespec *)
 	)
 {
+	time_t pivot; /* for ntp era unfolding */
 	struct timespec timets, tslast, tsdiff;
-	struct timespec ofs_ts; /* desired offset as teimspec */
+	struct calendar jd;
+	l_fp fp_ofs, fp_sys; /* offset and target system time in FP */
 
-	/* get the complete jump distance as timespec */
-        ofs_ts = d_to_tspec(step + sys_residual);
+	/*
+	 * Get pivot time for NTP era unfolding. Since we don't step
+	 * very often, we can afford to do the whole calculation from
+	 * scratch. And we're not in the time-critical path yet.
+	 */
+#if NTP_SIZEOF_TIME_T > 4
+	/*
+	 * This code makes sure the resulting time stamp for the new
+	 * system time is in the 2^32 seconds starting at 1970-01-01,
+	 * 00:00:00 UTC.
+	 */
+	pivot = 0x80000000;
+#if USE_COMPILETIME_PIVOT
+	/*
+	 * Add the compile time minus 10 years to get a possible target
+	 * area of (compile time - 10 years) to (compile time + 126
+	 * years).  This should be sufficient for a given binary of
+	 * NTPD.
+	 */
+	if (ntpcal_get_build_date(&jd)) {
+		jd.year -= 10;
+		pivot += ntpcal_date_to_time(&jd);
+	} else {
+		msyslog(LOG_ERR,
+			"CLOCK: step_systime: assume 1970-01-01 as build date");
+	}
+#else
+	UNUSED_LOCAL(jd);
+#endif /* USE_COMPILETIME_PIVOT */
+#else
+	UNUSED_LOCAL(jd);
+	/* This makes sure the resulting time stamp is on or after
+	 * 1969-12-31/23:59:59 UTC and gives us additional two years,
+	 * from the change of NTP era in 2036 to the UNIX rollover in
+	 * 2038. (Minus one second, but that won't hurt.) We *really*
+	 * need a longer 'time_t' after that!  Or a different baseline,
+	 * but that would cause other serious trouble, too.
+	 */
+	pivot = 0x7FFFFFFF;
+#endif
+
+	/* get the complete jump distance as l_fp */
+	fp_sys = dtolfp(sys_residual);
+	fp_ofs = dtolfp(step);
+	fp_ofs += fp_sys;
 
 	/* ---> time-critical path starts ---> */
 
-	/* get the current time as, without fuzz, as struct timespec */
+	/* get the current time as l_fp (without fuzz) and as struct timespec */
 	get_ostime(&timets);
+	fp_sys = tspec_stamp_to_lfp(timets);
 
-	/* add offset */
-	tslast = add_tspec(timets, ofs_ts);
+	/* get the target time as l_fp */
+	fp_sys += fp_ofs;
+
+	/* unfold the new system time */
+	timets = lfp_stamp_to_tspec(fp_sys, &pivot);
 
 	/* now set new system time */
-	if (settime(&tslast) != 0) {
-		msyslog(LOG_ERR, "step_systime: %m");
+	if (settime(&timets) != 0) {
+		msyslog(LOG_ERR, "CLOCK: step_systime: %m");
 		return false;
 	}
 
 	/* <--- time-critical path ended with call to the settime hook <--- */
 
+	msyslog(LOG_WARNING, "CLOCK: time stepped by %Lf", step);
+
 	/* only used for utmp/wtmpx time-step recording */
+	tslast.tv_sec = timets.tv_sec;
+	tslast.tv_nsec = timets.tv_nsec;
 
 	sys_residual = 0;
 	lamport_violated = (step < 0);
