@@ -32,6 +32,8 @@
 			if (pp->coderecv == pp->codeproc) \
 				pp->codeproc = (pp->codeproc + 1) % MAXSTAGE;
 
+#define TTY	struct termios
+
 /*
  * Reference clock support is provided here by maintaining the fiction
  * that the clock is actually a peer.  As no packets are exchanged with
@@ -69,6 +71,7 @@ bool	cal_enable;		/* enable refclock calibrate */
  */
 static int refclock_cmpl_fp (const void *, const void *);
 static int refclock_sample (struct refclockproc *);
+static bool refclock_setup (int, unsigned int, unsigned int);
 
 
 /*
@@ -127,7 +130,7 @@ refclock_name(
 {
 	char *buf;
 
-	LIB_GETBUF(buf);
+	buf = lib_getbuf();
 
 	snprintf(buf, LIB_BUFLENGTH, "%s(%d)",
 			 peer->procptr->clockname, peer->refclkunit);
@@ -177,7 +180,7 @@ refclock_newpeer(
 	if (clktype >= num_refclock_conf ||
 	    !refclock_conf[clktype]->clock_start) {
 		msyslog(LOG_ERR,
-			"refclock_newpeer: clock type %d invalid\n",
+			"REFCLOCK: refclock_newpeer: clock type %d invalid\n",
 			clktype);
 		return false;
 	}
@@ -192,10 +195,10 @@ refclock_newpeer(
 	 * Initialize structures
 	 */
 	peer->refclkunit = (uint8_t)unit;
-	peer->flags |= FLAG_REFCLOCK;
+	peer->cfg.flags |= FLAG_REFCLOCK;
 	peer->leap = LEAP_NOTINSYNC;
 	peer->stratum = STRATUM_REFCLOCK;
-	peer->ppoll = peer->maxpoll;
+	peer->ppoll = peer->cfg.maxpoll;
 	pp->conf = refclock_conf[clktype];
 	pp->timestarted = current_time;
 	pp->io.fd = -1;
@@ -297,11 +300,8 @@ refclock_transmit(
 	 */
 	if (peer->burst == 0) {
 		uint8_t oreach;
-#ifdef DEBUG
-		if (debug)
-			printf("refclock_transmit: at %ld %s\n",
-			    current_time, socktoa(&(peer->srcadr)));
-#endif
+		DPRINT(1, ("refclock_transmit: at %lu %s\n",
+			   current_time, socktoa(&(peer->srcadr))));
 
 		/*
 		 * Update reachability and poll variables like the
@@ -318,7 +318,7 @@ refclock_transmit(
 				peer->timereachable = current_time;
 			}
 		} else {
-			if (peer->flags & FLAG_BURST)
+			if (peer->cfg.flags & FLAG_BURST)
 				peer->burst = NSTAGE;
 		}
 	} else {
@@ -405,11 +405,11 @@ refclock_process_f(
 	 * Compute the timecode timestamp from the days, hours, minutes,
 	 * seconds and milliseconds/microseconds of the timecode. Use
 	 * clocktime() for the aggregate seconds and the msec/usec for
-	 * the fraction, when present. Note that this code relies on the
-	 * filesystem time for the years and does not use the years of
-	 * the timecode.
+	 * the fraction, when present. Note that this code will fall back
+	 * to deducing the year from the receipt time of the sample if
+	 * it finds only a 2-digit year in the timecode.
 	 */
-	if (!clocktime(pp->day, pp->hour, pp->minute, pp->second, GMT,
+	if (!clocktime(pp->year, pp->day, pp->hour, pp->minute, pp->second, GMT,
 		       lfpuint(pp->lastrec), &pp->yearstart, &sec))
 		return false;
 
@@ -492,12 +492,8 @@ refclock_sample(
 	}
 	pp->offset /= m;
 	pp->jitter = SQRT(pp->jitter / m);
-#ifdef DEBUG
-	if (debug)
-		printf(
-		    "refclock_sample: n %d offset %.6f disp %.6f jitter %.6f\n",
-		    (int)n, pp->offset, pp->disp, pp->jitter);
-#endif
+	DPRINT(1, ("refclock_sample: n %d offset %.6f disp %.6f jitter %.6f\n",
+		   (int)n, pp->offset, pp->disp, pp->jitter));
 	return (int)n;
 }
 
@@ -518,11 +514,8 @@ refclock_receive(
 {
 	struct refclockproc *pp;
 
-#ifdef DEBUG
-	if (debug)
-		printf("refclock_receive: at %lu %s\n",
-		    current_time, socktoa(&peer->srcadr));
-#endif
+	DPRINT(1, ("refclock_receive: at %lu %s\n",
+		   current_time, socktoa(&peer->srcadr)));
 
 	/*
 	 * Do a little sanity dance and update the peer structure. Groom
@@ -602,11 +595,11 @@ refclock_gtlin(
 	if (dlen)
 	    *dp  = '\0';
 	*tsptr = rbufp->recv_time;
-	DPRINTF(2, ("refclock_gtlin: fd %d time %s timecode %d %s\n",
-		    rbufp->fd, ulfptoa(rbufp->recv_time, 6), dlen,
-		    (dlen != 0)
-			? lineptr
-			: ""));
+	DPRINT(2, ("refclock_gtlin: fd %d time %s timecode %d %s\n",
+		   rbufp->fd, ulfptoa(rbufp->recv_time, 6), dlen,
+		   (dlen != 0)
+		   ? lineptr
+		   : ""));
 	return (dlen);
 }
 
@@ -643,9 +636,9 @@ refclock_gtraw(
 	lineptr[bmax] = '\0';
 
 	*tsptr = rbufp->recv_time;
-	DPRINTF(2, ("refclock_gtraw: fd %d time %s timecode %zd %s\n",
-		    rbufp->fd, ulfptoa(rbufp->recv_time, 6), bmax,
-		    lineptr));
+	DPRINT(2, ("refclock_gtraw: fd %d time %s timecode %zu %s\n",
+		   rbufp->fd, ulfptoa(rbufp->recv_time, 6), bmax,
+		   lineptr));
 	return (bmax);
 }
 
@@ -683,14 +676,6 @@ indicate_refclock_packet(
 }
 
 
-/*
- * process_refclock_packet()
- *
- * Used for deferred processing of 'io_input' on systems where threading
- * is used. This is acting as a trampoline to make the
- * real calls to the refclock functions.
- */
-
 /*
  * refclock_open - open serial port for reference clock
  *
@@ -700,9 +685,9 @@ indicate_refclock_packet(
  */
 int
 refclock_open(
-	char	*dev,		/* device name pointer */
-	u_int	speed,		/* serial port speed (code) */
-	u_int	lflags		/* line discipline flags */
+	char		*dev,		/* device name pointer */
+	unsigned int	speed,		/* serial port speed (code) */
+	unsigned int	lflags		/* line discipline flags */
 	)
 {
 	int	fd;
@@ -729,7 +714,7 @@ refclock_open(
 		close(0);
 	}
 	if (fd < 0) {
-		msyslog(LOG_ERR, "refclock_open %s: %m", dev);
+		msyslog(LOG_ERR, "REFCLOCK: refclock_open %s: %m", dev);
 		return -1;
 	}
 	if (!refclock_setup(fd, speed, lflags)) {
@@ -753,11 +738,11 @@ refclock_open(
 /*
  * refclock_setup - initialize terminal interface structure
  */
-bool
+static bool
 refclock_setup(
-	int	fd,		/* file descriptor */
-	u_int	speed,		/* serial port speed (code) */
-	u_int	lflags		/* line discipline flags */
+	int		fd,		/* file descriptor */
+	unsigned int	speed,		/* serial port speed (code) */
+	unsigned int	lflags		/* line discipline flags */
 	)
 {
 	int	i;
@@ -777,7 +762,8 @@ refclock_setup(
 	 * POSIX serial line parameters (termios interface)
 	 */
 	if (tcgetattr(fd, ttyp) < 0) {
-		msyslog(LOG_ERR, "refclock_setup fd %d tcgetattr: %m", fd);
+		msyslog(LOG_ERR,
+			"REFCLOCK: refclock_setup fd %d tcgetattr: %m", fd);
 		return false;
 	}
 
@@ -786,7 +772,7 @@ refclock_setup(
 	 * 8 bits and no parity; map CR to NL; ignore break.
 	 */
 	if (speed) {
-		u_int	ltemp = 0;
+		unsigned int	ltemp = 0;
 
 		ttyp->c_iflag = IGNBRK | IGNPAR | ICRNL;
 		ttyp->c_oflag = 0;
@@ -808,14 +794,11 @@ refclock_setup(
 		 */
 		if (ioctl(fd, TIOCMGET, (char *)&ltemp) < 0)
 			msyslog(LOG_ERR,
-			    "refclock_setup fd %d TIOCMGET: %m", fd);
-#ifdef DEBUG
-		if (debug)
-			printf("refclock_setup fd %d modem status: 0x%x\n",
-			    fd, ltemp);
-#endif
+			    "REFCLOCK: refclock_setup fd %d TIOCMGET: %m", fd);
+		DPRINT(1, ("REFCLOCK: refclock_setup fd %d modem status: 0x%x\n",
+			   fd, ltemp));
 		if (ltemp & TIOCM_DSR && lflags & LDISC_REMOTE)
-			ttyp->c_cflag &= ~CLOCAL;
+			ttyp->c_cflag &= (unsigned int)~CLOCAL;
 #endif /* TIOCMGET */
 	}
 
@@ -829,7 +812,7 @@ refclock_setup(
 		ttyp->c_cc[VMIN] = 1;
 	}
 	if (tcsetattr(fd, TCSANOW, ttyp) < 0) {
-		msyslog(LOG_ERR, "refclock_setup fd %d TCSANOW: %m", fd);
+		msyslog(LOG_ERR, "REFCLOCK: refclock_setup fd %d TCSANOW: %m", fd);
 		return false;
 	}
 
@@ -839,7 +822,7 @@ refclock_setup(
 	 * is logged, but we keep our fingers crossed otherwise.
 	 */
 	if (tcflush(fd, TCIOFLUSH) < 0)
-		msyslog(LOG_ERR, "refclock_setup fd %d tcflush(): %m",
+		msyslog(LOG_ERR, "REFCLOCK: refclock_setup fd %d tcflush(): %m",
 			fd);
 	return true;
 }
@@ -917,10 +900,10 @@ refclock_control(
 		out->fudgeval2 = pp->refid;
 		out->haveflags = CLK_HAVEVAL1 | CLK_HAVEVAL2;
 		out->fudgetime1 = pp->fudgetime1;
-		if (0.0 != out->fudgetime1)
+		if (!D_ISZERO_NS(out->fudgetime1))
 			out->haveflags |= CLK_HAVETIME1;
 		out->fudgetime2 = pp->fudgetime2;
-		if (0.0 != out->fudgetime2)
+		if (!D_ISZERO_NS(out->fudgetime2))
 			out->haveflags |= CLK_HAVETIME2;
 		out->flags = (uint8_t) pp->sloppyclockflag;
 		if (CLK_FLAG1 & out->flags)
@@ -942,7 +925,7 @@ refclock_control(
 		out->currentstatus = pp->currentstatus;
 		out->clockname = pp->clockname;
 		out->clockdesc = pp->clockdesc;
-		out->lencode = (u_short)pp->lencode;
+		out->lencode = (unsigned short)pp->lencode;
 		out->p_lastcode = pp->a_lastcode;
 	}
 
@@ -970,7 +953,7 @@ refclock_ppsapi(
 	if (ap->handle == 0) {
 		if (time_pps_create(fddev, &ap->handle) < 0) {
 			msyslog(LOG_ERR,
-			    "refclock_ppsapi: time_pps_create: %m");
+			    "REFCLOCK: refclock_ppsapi: time_pps_create: %m");
 			return false;
 		}
 	}
@@ -1004,7 +987,7 @@ refclock_params(
 		ap->pps_params.mode = PPS_TSFMT_TSPEC | PPS_CAPTUREASSERT;
 	if (time_pps_setparams(ap->handle, &ap->pps_params) < 0) {
 		msyslog(LOG_ERR,
-		    "refclock_params: time_pps_setparams: %m");
+		    "REFCLOCK: refclock_params: time_pps_setparams: %m");
 		return false;
 	}
 
@@ -1017,10 +1000,10 @@ refclock_params(
 		    PPS_TSFMT_TSPEC) < 0) {
 			if (errno == EOPNOTSUPP)
 			    msyslog(LOG_ERR,
-				"refclock_params: kernel PLL (hardpps, RFC 1589) not implemented");
+				"REFCLOCK: refclock_params: kernel PLL (hardpps, RFC 1589) not implemented");
 			else
 			    msyslog(LOG_ERR,
-				"refclock_params: time_pps_kcbind: %m");
+				"REFCLOCK: refclock_params: time_pps_kcbind: %m");
 			return false;
 		}
 		hardpps_enable = true;
@@ -1099,11 +1082,8 @@ refclock_catcher(
 	if (dtemp > .5)
 		dtemp -= 1.;
 	SAMPLE(-dtemp + pp->fudgetime1);
-#ifdef DEBUG
-	if (debug > 1)
-		printf("refclock_pps: %lu %f %f\n", current_time,
-		    dtemp, pp->fudgetime1);
-#endif
+	DPRINT(2, ("refclock_pps: %lu %f %f\n", current_time,
+		   dtemp, pp->fudgetime1));
 	return PPS_OK;
 }
 #endif /* HAVE_PPSAPI */
