@@ -22,6 +22,7 @@
 # define	TC_ERR	(-1)
 #endif
 
+#define	EVENT_TIMEOUT	0	/* one second, that is */
 
 static void check_leapsec(time_t, bool);
 
@@ -40,29 +41,28 @@ volatile int interface_interval;     /* init_io() sets def. 300s */
 /*
  * The counters and timeouts
  */
-static  u_long interface_timer;	/* interface update timer */
-static	u_long adjust_timer;	/* second timer */
-static	u_long stats_timer;	/* stats timer */
-static	u_long leapf_timer;	/* Report leapfile problems once/day */
-static	u_long huffpuff_timer;	/* huff-n'-puff timer */
-static	u_long worker_idle_timer;/* next check for idle intres */
-u_long	leapsec;	        /* seconds to next leap (proximity class) */
-int	leap_smear_intv;	/* Duration of smear.  Enables smear mode. */
+static unsigned long interface_timer;	/* interface update timer */
+static unsigned long adjust_timer;	/* second timer */
+static unsigned long stats_timer;	/* stats timer */
+static unsigned long leapf_timer;	/* Report leapfile problems once/day */
+static unsigned long huffpuff_timer;	/* huff-n'-puff timer */
+unsigned long	leapsec;	        /* secs to next leap (proximity class) */
+unsigned int	leap_smear_intv;	/* Duration of smear.  Enables smear mode. */
 int	leapdif;		/* TAI difference step at next leap second*/
-u_long	orphwait; 		/* orphan wait time */
+unsigned long	orphwait; 	/* orphan wait time */
 
 /*
  * Statistics counter for the interested.
  */
-volatile u_long alarm_overflow;
+volatile unsigned long alarm_overflow;
 
-u_long current_time;		/* seconds since startup */
+unsigned long current_time;		/* seconds since startup */
 
 /*
  * Stats.  Time of last reset and number of calls to transmit().
  */
-u_long timer_timereset;
-u_long timer_xmtcalls;
+unsigned long timer_timereset;
+unsigned long timer_xmtcalls;
 
 static	void catchALRM (int);
 
@@ -97,7 +97,7 @@ set_timer_or_die(
 	rc = setitimer(ITIMER_REAL, &itimer, NULL);
 #endif
 	if (-1 == rc) {
-		msyslog(LOG_ERR, "interval timer %s failed, %m",
+		msyslog(LOG_ERR, "ERR:interval timer %s failed, %m",
 			setfunc);
 		exit(1);
 	}
@@ -157,7 +157,7 @@ init_timer(void)
 	 */
 #ifdef HAVE_TIMER_CREATE
 	if (TC_ERR == timer_create(CLOCK_REALTIME, NULL, &timer_id)) {
-		msyslog(LOG_ERR, "timer_create failed, %m");
+		msyslog(LOG_ERR, "ERR: timer_create failed, %m");
 		exit(1);
 	}
 #endif
@@ -169,27 +169,6 @@ init_timer(void)
 }
 
 
-/*
- * intres_timeout_req(s) is invoked in the parent to schedule an idle
- * timeout to fire in s seconds, if not reset earlier by a call to
- * intres_timeout_req(0), which clears any pending timeout.  When the
- * timeout expires, worker_idle_timer_fired() is invoked (again, in the
- * parent).
- *
- * ntpdig and ntpd each provide implementations adapted to their timers.
- */
-void
-intres_timeout_req(
-	u_int	seconds		/* 0 cancels */
-	)
-{
-	if (0 == seconds) {
-		worker_idle_timer = 0;
-		return;
-	}
-	worker_idle_timer = current_time + seconds;
-}
-
 
 /*
  * timer - event timer
@@ -213,7 +192,7 @@ timer(void)
 #ifdef REFCLOCK
 		for (p = peer_list; p != NULL; p = next_peer) {
 			next_peer = p->p_link;
-			if (FLAG_REFCLOCK & p->flags)
+			if (FLAG_REFCLOCK & p->cfg.flags)
 				refclock_timer(p);
 		}
 #endif /* REFCLOCK */
@@ -237,7 +216,7 @@ timer(void)
 			p->throttle--;
 		if (p->nextdate <= current_time) {
 #ifdef REFCLOCK
-			if (FLAG_REFCLOCK & p->flags)
+			if (FLAG_REFCLOCK & p->cfg.flags)
 				refclock_transmit(p);
 			else
 #endif	/* REFCLOCK */
@@ -300,13 +279,10 @@ timer(void)
 	if (interface_interval && interface_timer <= current_time) {
 		timer_interfacetimeout(current_time +
 		    (unsigned long)interface_interval);
-		DPRINTF(2, ("timer: interface update\n"));
+		DPRINT(2, ("timer: interface update\n"));
 		interface_update(NULL, NULL);
 	}
 
-	if (worker_idle_timer && worker_idle_timer <= current_time)
-		worker_idle_timer_fired();
-
 	/*
 	 * Finally, write hourly stats and do the hourly
 	 * and daily leapfile checks.
@@ -356,7 +332,7 @@ if (debug >= 4 && msg != NULL)
 
 
 void
-timer_interfacetimeout(u_long timeout)
+timer_interfacetimeout(unsigned long timeout)
 {
 	interface_timer = timeout;
 }
@@ -416,8 +392,10 @@ check_leapsec(
 	} else {
 		int fired = leapsec_query(&lsdata, now);
 
-		DPRINTF(1, ("*** leapsec_query: fired %i, now %lli (0x%llX), tai_diff %i, ddist %u\n",
-		      fired, (long long)now, (long long)now, lsdata.tai_diff, lsdata.ddist));
+		DPRINT(1, ("*** leapsec_query: fired %i, now %lli (0x%llX), "
+			   "tai_diff %i, ddist %u\n",
+			   fired, (long long)now, (long long unsigned)now,
+			   lsdata.tai_diff, lsdata.ddist));
 #ifdef ENABLE_LEAP_SMEAR
 		leap_smear.in_progress = false;
 		leap_smear.doffset = 0.0;
@@ -428,13 +406,13 @@ check_leapsec(
 				      leap_smear.interval = leap_smear_intv;
 				      leap_smear.intv_end = lsdata.ttime;
 				      leap_smear.intv_start = leap_smear.intv_end - leap_smear.interval;
-				      DPRINTF(1, ("*** leapsec_query: setting leap_smear interval %li, begin %.0f, end %.0f\n",
-					      leap_smear.interval, leap_smear.intv_start, leap_smear.intv_end));
+				      DPRINT(1, ("*** leapsec_query: setting leap_smear interval %li, begin %.0f, end %.0f\n",
+						 leap_smear.interval, leap_smear.intv_start, leap_smear.intv_end));
 			      }
 		      }
 		      else {
 			      if (leap_smear.interval)
-				      DPRINTF(1, ("*** leapsec_query: clearing leap_smear interval\n"));
+				      DPRINT(1, ("*** leapsec_query: clearing leap_smear interval\n"));
 			      leap_smear.interval = 0;
 		      }
 
@@ -456,13 +434,13 @@ check_leapsec(
 				       */
 				      leap_smear.in_progress = true;
 #if 0 && defined( DEBUG )
-				      msyslog(LOG_NOTICE, "*** leapsec_query: [%.0f:%.0f] (%li), now %u (%.0f), smear offset %.6f ms\n",
+				      msyslog(LOG_NOTICE, "CLOCK: *** leapsec_query: [%.0f:%.0f] (%li), now %u (%.0f), smear offset %.6f ms\n",
 					      leap_smear.intv_start, leap_smear.intv_end, leap_smear.interval,
 					      now, leap_smear_time, leap_smear.doffset);
 #else
-				      DPRINTF(1, ("*** leapsec_query: [%.0f:%.0f] (%li), now %lld (%.0f), smear offset %.6f ms\n",
-					      leap_smear.intv_start, leap_smear.intv_end, leap_smear.interval,
-					      (long long)now, leap_smear_time, leap_smear.doffset));
+				      DPRINT(1, ("*** leapsec_query: [%.0f:%.0f] (%li), now %lld (%.0f), smear offset %.6f ms\n",
+						 leap_smear.intv_start, leap_smear.intv_end, leap_smear.interval,
+						 (long long)now, leap_smear_time, leap_smear.doffset));
 #endif
 
 			      }
@@ -500,14 +478,14 @@ check_leapsec(
 				}
 			}
 			if (leapmsg)
-				msyslog(LOG_NOTICE, "%s", leapmsg);
+				msyslog(LOG_NOTICE, "CLOCK: %s", leapmsg);
 			report_event(EVNT_LEAP, NULL, NULL);
 			lsprox  = LSPROX_NOWARN;
 			leapsec = LSPROX_NOWARN;
-			sys_tai = (u_int)lsdata.tai_offs;
+			sys_tai = (unsigned int)lsdata.tai_offs;
 		} else {
 			lsprox  = lsdata.proximity;
-			sys_tai = (u_int)lsdata.tai_offs;
+			sys_tai = (unsigned int)lsdata.tai_offs;
 		}
 	}
 
