@@ -10,6 +10,7 @@
 #include "ntp_filegen.h"
 #include "ntp_leapsec.h"
 #include "ntp_stdlib.h"
+#include "ntp_stdlib.h"
 #include "ntpd.h"
 #include "timespecops.h"
 
@@ -26,9 +27,9 @@
 #endif
 
 /*
- * Defines used by the leapseconds stuff
+ * Defines used by file logging
  */
-#define MJD_1900		15020	/* MJD for 1 Jan 1900 */
+#define MJD_1970        40587           /* MJD for 1 Jan 1970 */
 
 /*
  * This contains odds and ends, including the hourly stats, various
@@ -44,6 +45,7 @@ static bool have_leapfile = false;
 char *stats_drift_file;			/* frequency file name */
 static double wander_resid;		/* last frequency update */
 double	wander_threshold = 1e-7;	/* initial frequency threshold */
+static char *timespec_to_MJDtime(const struct timespec *);
 
 /*
  * Statistics file stuff
@@ -145,29 +147,27 @@ init_util(void)
 /*
  * hourly_stats - print some interesting stats
  */
-#define IGNORE(r) do{if(r){}}while(0)
-
 static void drift_write(char *driftfile, double drift)
 {
 	int fd;
-	char tmpfile[PATH_MAX], driftcopy[PATH_MAX];
+	char tempfile[PATH_MAX], driftcopy[PATH_MAX];
 	char driftval[32];
 	strlcpy(driftcopy, driftfile, PATH_MAX);
-	strlcpy(tmpfile, dirname(driftcopy), sizeof(tmpfile));
-	strlcat(tmpfile, "/driftXXXXXX", sizeof(tmpfile));
+	strlcpy(tempfile, dirname(driftcopy), sizeof(tempfile));
+	strlcat(tempfile, "/driftXXXXXX", sizeof(tempfile));
 	/* coverity[secure_temp] Warning is bogus on POSIX-compliant systems */
-	if ((fd = mkstemp(tmpfile)) < 0) {
-	    msyslog(LOG_ERR, "frequency file %s: %m", tmpfile);
+	if ((fd = mkstemp(tempfile)) < 0) {
+	    msyslog(LOG_ERR, "LOG: frequency file %s: %m", tempfile);
 	    return;
 	}
 	snprintf(driftval, sizeof(driftval), "%.6f\n", drift);
 	IGNORE(write(fd, driftval, strlen(driftval)));
 	(void)close(fd);
 	/* atomic */
-	if (rename(tmpfile, driftfile))
+	if (rename(tempfile, driftfile))
 	    msyslog(LOG_WARNING,
-		    "Unable to rename temp drift file %s to %s, %m",
-		    tmpfile, driftfile);
+		    "LOG: Unable to rename temp drift file %s to %s, %m",
+		    tempfile, driftfile);
 }
 void
 write_stats(void)
@@ -185,12 +185,9 @@ write_stats(void)
 		 * the frequncy file. This minimizes the file writes to
 		 * nonvolaile storage.
 		 */
-#ifdef DEBUG
-		if (debug)
-			printf("write_stats: frequency %.6lf thresh %.6lf, freq %.6lf\n",
-			    (prev_drift_comp - drift_comp) * US_PER_S,
-                             wander_resid * US_PER_S, drift_comp * US_PER_S);
-#endif
+	        DPRINT(1, ("write_stats: frequency %.6lf thresh %.6lf, freq %.6lf\n",
+			   (prev_drift_comp - drift_comp) * US_PER_S,
+			   wander_resid * US_PER_S, drift_comp * US_PER_S));
 		if (fabs(prev_drift_comp - drift_comp) < wander_resid) {
 			wander_resid *= 0.5;
 			return;
@@ -202,9 +199,6 @@ write_stats(void)
 }
 
 
-/*
- * stats_config - configure the stats operation
- */
 static bool drift_read(const char *drift_file, double *drift)
 {
 	FILE *fp;
@@ -213,7 +207,7 @@ static bool drift_read(const char *drift_file, double *drift)
 	}
 	if (fscanf(fp, "%lf", drift) != 1) {
 	    msyslog(LOG_ERR,
-		    "format error frequency file %s",
+		    "LOG: format error frequency file %s",
 		    drift_file);
 	    fclose(fp);
 	    return false;
@@ -222,6 +216,9 @@ static bool drift_read(const char *drift_file, double *drift)
 	return true;
 }
 
+/*
+ * stats_config - configure the stats operation
+ */
 void
 stats_config(
 	int item,
@@ -266,7 +263,7 @@ stats_config(
 		/* - 1 since value may be missing the DIR_SEP. */
 		if (strlen(value) >= sizeof(statsdir) - 1) {
 			msyslog(LOG_ERR,
-			    "statsdir too long (>%d, sigh)",
+			    "LOG: statsdir too long (>%d, sigh)",
 			    (int)sizeof(statsdir) - 2);
 		} else {
 			bool add_dir_sep;
@@ -295,7 +292,7 @@ stats_config(
 	 */
 	case STATS_PID_FILE:
 		if ((fp = fopen(value, "w")) == NULL) {
-			msyslog(LOG_ERR, "pid file %s: %m",
+			msyslog(LOG_ERR, "LOG: pid file %s: %m",
 			    value);
 			break;
 		}
@@ -347,6 +344,37 @@ stats_config(
 	}
 }
 
+/* timespec_to_MJDtime
+ */
+
+static char *
+timespec_to_MJDtime(const struct timespec *ts)
+{
+	char *buf;
+	unsigned long	day, sec, msec;
+
+	buf = lib_getbuf();
+
+	day = (unsigned long)ts->tv_sec / SECSPERDAY + MJD_1970;
+	sec = (unsigned long)ts->tv_sec % SECSPERDAY;
+	msec = (unsigned long)ts->tv_nsec / NS_PER_MS;  /* nano secs to milli sec */
+	snprintf(buf, LIB_BUFLENGTH, "%lu %lu.%03lu", day, sec, msec);
+
+	return buf;
+}
+
+
+static const char *
+peerlabel(const struct peer *peer)
+{
+#if defined(REFCLOCK) && !defined(ENABLE_CLASSIC_MODE)
+	if (peer->procptr != NULL)
+		return refclock_name(peer);
+	else
+#endif /* defined(REFCLOCK) && !defined(ENABLE_CLASSIC_MODE)*/
+		return socktoa(&peer->srcadr);
+}
+
 /*
  * record_peer_stats - write peer statistics to file
  *
@@ -366,36 +394,23 @@ record_peer_stats(
 	int	status
 	)
 {
-	l_fp	now;
-	u_long	day;
+	struct timespec now;
 
 	if (!stats_control)
 		return;
 
-	get_systime(&now);
-	filegen_setup(&peerstats, lfpuint(now));
-	day = lfpuint(now) / 86400 + MJD_1900;
-	setlfpuint(now, lfpuint(now) % 86400);
+	clock_gettime(CLOCK_REALTIME, &now);
+	filegen_setup(&peerstats, now.tv_sec);
 	if (peerstats.fp != NULL) {
 		fprintf(peerstats.fp,
-		    "%lu %s %s %x %.9f %.9f %.9f %.9f\n", day,
-		    ulfptoa(now, 3), socktoa(&peer->srcadr), status, peer->offset,
+		    "%s %s %x %.9f %.9f %.9f %.9f\n",
+		    timespec_to_MJDtime(&now),
+		    peerlabel(peer), (unsigned int)status, peer->offset,
 		    peer->delay, peer->disp, peer->jitter);
 		fflush(peerstats.fp);
 	}
 }
 
-static const char *
-peerlabel(const struct peer *peer)
-{
-#if defined(REFCLOCK) && !defined(ENABLE_CLASSIC_MODE)
- 	if (peer->procptr != NULL)
-		return refclock_name(peer);
-	else
-#endif /* defined(REFCLOCK) && !defined(ENABLE_CLASSIC_MODE)*/
-		return socktoa(&peer->srcadr);
-}
-
 /*
  * record_loop_stats - write loop filter statistics to file
  *
@@ -417,19 +432,17 @@ record_loop_stats(
 	int spoll
 	)
 {
-	l_fp	now;
-	u_long	day;
+	struct timespec	now;
 
 	if (!stats_control)
 		return;
 
-	get_systime(&now);
-	filegen_setup(&loopstats, lfpuint(now));
-	day = lfpuint(now) / 86400 + MJD_1900;
-	setlfpuint(now, lfpuint(now) % 86400);
+	clock_gettime(CLOCK_REALTIME, &now);
+	filegen_setup(&loopstats, now.tv_sec);
 	if (loopstats.fp != NULL) {
-		fprintf(loopstats.fp, "%lu %s %.9f %.6f %.9f %.6f %d\n",
-		    day, ulfptoa(now, 3), offset, freq * US_PER_S, jitter,
+		fprintf(loopstats.fp, "%s %.9f %.6f %.9f %.6f %d\n",
+		    timespec_to_MJDtime(&now),
+		    offset, freq * US_PER_S, jitter,
 		    wander * US_PER_S, spoll);
 		fflush(loopstats.fp);
 	}
@@ -451,19 +464,16 @@ record_clock_stats(
 	const char *text	/* timecode string */
 	)
 {
-	l_fp	now;
-	u_long	day;
+	struct timespec	now;
 
 	if (!stats_control)
 		return;
 
-	get_systime(&now);
-	filegen_setup(&clockstats, lfpuint(now));
-	day = lfpuint(now) / 86400 + MJD_1900;
-	setlfpuint(now, lfpuint(now) % 86400);
+	clock_gettime(CLOCK_REALTIME, &now);
+	filegen_setup(&clockstats, now.tv_sec);
 	if (clockstats.fp != NULL) {
-		fprintf(clockstats.fp, "%lu %s %s %s\n", day,
-		    ulfptoa(now, 3), peerlabel(peer), text);
+		fprintf(clockstats.fp, "%s %s %s\n",
+		    timespec_to_MJDtime(&now), peerlabel(peer), text);
 		fflush(clockstats.fp);
 	}
 }
@@ -499,18 +509,14 @@ mprintf_clock_stats(
  * file format
  * day (MJD)
  * time (s past midnight)
- * peer ip address
- * IP address old format) or drivername(unit) (new format)
+ * source IP address old format) or drivername(unit) (new format)
+ * destination peer address 
  * t1 t2 t3 t4 timestamps
+ * various other local statistics
  */
 void
 record_raw_stats(
-	sockaddr_u *srcadr,
-	sockaddr_u *dstadr,
-	l_fp	*t1,		/* originate timestamp */
-	l_fp	*t2,		/* receive timestamp */
-	l_fp	*t3,		/* transmit timestamp */
-	l_fp	*t4,		/* destination timestamp */
+	struct peer *peer,
 	int	leap,
 	int	version,
 	int	mode,
@@ -520,25 +526,27 @@ record_raw_stats(
 	double	root_delay,	/* seconds */
 	double	root_dispersion,/* seconds */
 	uint32_t	refid,
-	u_int	outcount
+	unsigned int	outcount
 	)
 {
-	l_fp	now;
-	u_long	day;
+	struct timespec	now;
+	const sockaddr_u *dstaddr = peer->dstadr ? &peer->dstadr->sin : NULL;
+	l_fp	t1 = peer->org;		/* originate timestamp */
+	l_fp	t2 = peer->rec;		/* receive timestamp */
+	l_fp	t3 = peer->xmt;		/* transmit timestamp */
+	l_fp	t4 = peer->dst;		/* destination timestamp */
 
 	if (!stats_control)
 		return;
 
-	get_systime(&now);
-	filegen_setup(&rawstats, lfpuint(now));
-	day = lfpuint(now) / 86400 + MJD_1900;
-	setlfpuint(now, lfpuint(now) % 86400);
+	clock_gettime(CLOCK_REALTIME, &now);
+	filegen_setup(&rawstats, now.tv_sec);
 	if (rawstats.fp != NULL) {
-		fprintf(rawstats.fp, "%lu %s %s %s %s %s %s %s %d %d %d %d %d %d %.6f %.6f %s %d\n",
-		    day, ulfptoa(now, 3),
-		    socktoa(srcadr), dstadr ?  socktoa(dstadr) : "-",
-		    ulfptoa(*t1, 9), ulfptoa(*t2, 9),
-		    ulfptoa(*t3, 9), ulfptoa(*t4, 9),
+		fprintf(rawstats.fp, "%s %s %s %s %s %s %s %d %d %d %d %d %d %.6f %.6f %s %u\n",
+		    timespec_to_MJDtime(&now),
+		    peerlabel(peer), dstaddr ?  socktoa(dstaddr) : "-",
+		    ulfptoa(t1, 9), ulfptoa(t2, 9),
+		    ulfptoa(t3, 9), ulfptoa(t4, 9),
 		    leap, version, mode, stratum, ppoll, precision,
 		    root_delay, root_dispersion, refid_str(refid, stratum),
 		    outcount);
@@ -568,20 +576,17 @@ record_raw_stats(
 void
 record_sys_stats(void)
 {
-	l_fp	now;
-	u_long	day;
+	struct timespec	now;
 
 	if (!stats_control)
 		return;
 
-	get_systime(&now);
-	filegen_setup(&sysstats, lfpuint(now));
-	day = lfpuint(now) / 86400 + MJD_1900;
-	setlfpuint(now, lfpuint(now) % 86400);
+	clock_gettime(CLOCK_REALTIME, &now);
+	filegen_setup(&sysstats, now.tv_sec);
 	if (sysstats.fp != NULL) {
 		fprintf(sysstats.fp,
-		    "%lu %s %lu %lu %lu %lu %lu %lu %lu %lu %lu %lu %lu\n",
-		    day, ulfptoa(now, 3), current_time - sys_stattime,
+		    "%s %lu %lu %lu %lu %lu %lu %lu %lu %lu %lu %lu\n",
+		    timespec_to_MJDtime(&now), current_time - sys_stattime,
 		    sys_received, sys_processed, sys_newversion,
 		    sys_oldversion, sys_restricted, sys_badlength,
 		    sys_badauth, sys_declined, sys_limitrejected,
@@ -603,8 +608,7 @@ record_sys_stats(void)
 void record_use_stats(void)
 {
 #ifdef HAVE_GETRUSAGE
-	l_fp	now;
-	u_long	day;
+	struct timespec	now;
 	struct rusage usage;
 	static struct rusage oldusage;
 	/* Descriptions in NetBSD and FreeBSD are better than Linux
@@ -613,23 +617,21 @@ void record_use_stats(void)
 	if (!stats_control)
 		return;
 
-	get_systime(&now);
-	filegen_setup(&usestats, lfpuint(now));
-	day = lfpuint(now) / 86400 + MJD_1900;
-	setlfpuint(now, lfpuint(now) % 86400);
+	clock_gettime(CLOCK_REALTIME, &now);
+	filegen_setup(&usestats, now.tv_sec);
 	if (usestats.fp != NULL) {
-		double utime, stime;
+		double utime, stimex;
 		getrusage(RUSAGE_SELF, &usage);
 		utime =  usage.ru_utime.tv_usec - oldusage.ru_utime.tv_usec;
 		utime /= 1E6;
 		utime += usage.ru_utime.tv_sec -  oldusage.ru_utime.tv_sec;
-		stime =  usage.ru_stime.tv_usec - oldusage.ru_stime.tv_usec;
-		stime /= 1E6;
-		stime += usage.ru_stime.tv_sec -  oldusage.ru_stime.tv_sec;
+		stimex =  usage.ru_stime.tv_usec - oldusage.ru_stime.tv_usec;
+		stimex /= 1E6;
+		stimex += usage.ru_stime.tv_sec -  oldusage.ru_stime.tv_sec;
 		fprintf(usestats.fp,
-		    "%lu %s %lu %.3f %.3f %lu %lu %lu %lu %lu %lu %lu %lu %lu\n",
-		    day, ulfptoa(now, 3), current_time - use_stattime,
-		    utime, stime,
+		    "%s %lu %.3f %.3f %ld %ld %ld %ld %ld %ld %ld %ld %ld\n",
+		    timespec_to_MJDtime(&now), current_time - use_stattime,
+		    utime, stimex,
 		    usage.ru_minflt -   oldusage.ru_minflt,
 		    usage.ru_majflt -   oldusage.ru_majflt,
 		    usage.ru_nswap -    oldusage.ru_nswap,
@@ -660,19 +662,16 @@ record_proto_stats(
 	char	*str		/* text string */
 	)
 {
-	l_fp	now;
-	u_long	day;
+	struct timespec	now;
 
 	if (!stats_control)
 		return;
 
-	get_systime(&now);
-	filegen_setup(&protostats, lfpuint(now));
-	day = lfpuint(now) / 86400 + MJD_1900;
-	setlfpuint(now, lfpuint(now) % 86400);
+	clock_gettime(CLOCK_REALTIME, &now);
+	filegen_setup(&protostats, now.tv_sec);
 	if (protostats.fp != NULL) {
-		fprintf(protostats.fp, "%lu %s %s\n", day,
-		    ulfptoa(now, 3), str);
+		fprintf(protostats.fp, "%s %s\n",
+		    timespec_to_MJDtime(&now), str);
 		fflush(protostats.fp);
 	}
 }
@@ -692,19 +691,16 @@ record_timing_stats(
 	)
 {
 	static unsigned int flshcnt;
-	l_fp	now;
-	u_long	day;
+	struct timespec	now;
 
 	if (!stats_control)
 		return;
 
-	get_systime(&now);
-	filegen_setup(&timingstats, lfpuint(now));
-	day = lfpuint(now) / 86400 + MJD_1900;
-	setlfpuint(now, lfpuint(now) % 86400);
+	clock_gettime(CLOCK_REALTIME, &now);
+	filegen_setup(&timingstats, now.tv_sec);
 	if (timingstats.fp != NULL) {
-		fprintf(timingstats.fp, "%lu %s %s\n", day, lfptoa(now,
-		    3), text);
+		fprintf(timingstats.fp, "%s %s\n",
+		    timespec_to_MJDtime(&now), text);
 		if (++flshcnt % 100 == 0)
 			fflush(timingstats.fp);
 	}
@@ -761,16 +757,16 @@ check_leap_expiration(
 	rc = leapsec_daystolive(systime);
 	if (rc == 0) {
 		msyslog(LOG_WARNING,
-			"%s ('%s'): will expire in less than one day",
+			"CLOCK: %s ('%s'): will expire in less than one day",
 			logPrefix, leapfile_name);
 	} else if (is_daily_check && rc < 28) {
 		if (rc < 0)
 			msyslog(LOG_ERR,
-				"%s ('%s'): expired less than %d day%s ago",
+				"CLOCK: %s ('%s'): expired less than %d day%s ago",
 				logPrefix, leapfile_name, -rc, (rc == -1 ? "" : "s"));
 		else
 			msyslog(LOG_WARNING,
-				"%s ('%s'): will expire in less than %d days",
+				"CLOCK: %s ('%s'): will expire in less than %d days",
 				logPrefix, leapfile_name, 1+rc);
 	}
 }
@@ -796,30 +792,6 @@ getauthkeys(
 	authreadkeys(key_file_name);
 }
 
-
-/*
- * rereadkeys - read the authentication key file over again.
- */
-void
-rereadkeys(void)
-{
-	if (NULL != key_file_name)
-		authreadkeys(key_file_name);
-}
-
-
-#ifdef __UNUSED__
-/*
- * ntp_exit - document explicitly that ntpd has exited
- */
-void
-ntp_exit(int retval)
-{
-	msyslog(LOG_ERR, "EXITING with return code %d", retval);
-	exit(retval);
-}
-#endif
-
 /*
  * ntpd_time_stepped is called back by step_systime(), allowing ntpd
  * to do any one-time processing necessitated by the step.
@@ -827,7 +799,7 @@ ntp_exit(int retval)
 void
 ntpd_time_stepped(void)
 {
-	u_int saved_mon_enabled;
+	unsigned int saved_mon_enabled;
 
 	/*
 	 * flush the monitor MRU list which contains l_fp timestamps
