@@ -18,6 +18,9 @@
  * The claimed accuracy of this clock is 100 ns relative to the PPS
  * output when receiving four or more satellites.
  *
+ * WARNING: This driver depends on the system clock for year disambiguation.
+ * It will thus not be usable for recovery if the system clock is trashed.  
+ *
  * The receiver should be configured before starting the NTP daemon, in
  * order to establish reliable position and operating conditions. It
  * does not initiate surveying or hold mode. For use with NTP, the
@@ -94,8 +97,8 @@
 #define MAXSTA		40		/* max length of status string */
 #define MAXPOS		80		/* max length of position string */
 
-#define COMMAND_HALT_BCAST ( (peer->ttl % 2) ? "O0" : "B0" )
-#define COMMAND_START_BCAST ( (peer->ttl % 2) ? "O5" : "B5" )
+#define COMMAND_HALT_BCAST ( (peer->cfg.ttl % 2) ? "O0" : "B0" )
+#define COMMAND_START_BCAST ( (peer->cfg.ttl % 2) ? "O5" : "B5" )
 
 /*
  * ARB unit control structure
@@ -139,7 +142,7 @@ arb_start(
 	struct peer *peer
 	)
 {
-	register struct arbunit *up;
+	struct arbunit *up;
 	struct refclockproc *pp;
 	int fd;
 	char device[20];
@@ -148,8 +151,8 @@ arb_start(
 	 * Open serial port. Use CLK line discipline, if available.
 	 */
 	snprintf(device, sizeof(device), DEVICE, unit);
-	fd = refclock_open(peer->path ? peer->path : device,
-			   peer->baud ? peer->baud : SPEED232, LDISC_CLK);
+	fd = refclock_open(peer->cfg.path ? peer->cfg.path : device,
+			   peer->cfg.baud ? peer->cfg.baud : SPEED232, LDISC_CLK);
 	if (fd <= 0)
 		/* coverity[leaked_handle] */
 		return false;
@@ -179,16 +182,14 @@ arb_start(
 	pp->clockdesc = DESCRIPTION;
 	memcpy((char *)&pp->refid, REFID, REFIDLEN);
 	peer->sstclktype = CTL_SST_TS_UHF;
-	if (peer->ttl > 1) {
-		msyslog(LOG_NOTICE, "ARBITER: Invalid mode %d", peer->ttl);
+	if (peer->cfg.ttl > 1) {
+		msyslog(LOG_NOTICE, "REFCLOCK ARBITER: Invalid mode %u", peer->cfg.ttl);
 		close(fd);
 		pp->io.fd = -1;
 		free(up);
 		return false;
 	}
-#ifdef DEBUG
-	if(debug) { printf("arbiter: mode = %d.\n", peer->ttl); }
-#endif
+	DPRINT(1, ("arbiter: mode = %u.\n", peer->cfg.ttl));
 	IGNORE(write(pp->io.fd, COMMAND_HALT_BCAST, 2));
 	return true;
 }
@@ -203,7 +204,7 @@ arb_shutdown(
 	struct peer *peer
 	)
 {
-	register struct arbunit *up;
+	struct arbunit *up;
 	struct refclockproc *pp;
 
 	UNUSED_ARG(unit);
@@ -225,7 +226,7 @@ arb_receive(
 	struct recvbuf *rbufp
 	)
 {
-	register struct arbunit *up;
+	struct arbunit *up;
 	struct refclockproc *pp;
 	struct peer *peer;
 	l_fp trtmp;
@@ -309,10 +310,7 @@ arb_receive(
 			strlcat(up->latlon, " ", sizeof(up->latlon));
 			strlcat(up->latlon, tbuf + 2, sizeof(up->latlon));
 			record_clock_stats(peer, up->latlon);
-#ifdef DEBUG
-			if (debug)
-				printf("arbiter: %s\n", up->latlon);
-#endif
+			DPRINT(1, ("arbiter: %s\n", up->latlon));
 			IGNORE(write(pp->io.fd, COMMAND_START_BCAST, 2));
 		}
 	}
@@ -430,7 +428,7 @@ arb_poll(
 	struct peer *peer
 	)
 {
-	register struct arbunit *up;
+	struct arbunit *up;
 	struct refclockproc *pp;
 
 	UNUSED_ARG(unit);
@@ -460,10 +458,7 @@ arb_poll(
 	}
 	refclock_receive(peer);
 	record_clock_stats(peer, pp->a_lastcode);
-#ifdef DEBUG
-	if (debug)
-		printf("arbiter: timecode %d %s\n",
-		   pp->lencode, pp->a_lastcode);
-#endif
+	DPRINT(1, ("arbiter: timecode %d %s\n",
+		   pp->lencode, pp->a_lastcode));
 }
 
