@@ -169,7 +169,7 @@ typedef unsigned long int json_uint;
 #define MAX_PDU_LEN	1600
 #define TICKOVER_LOW	10
 #define TICKOVER_HIGH	120
-#define LOGTHROTTLE	3600
+#define LOGTHROTTLE	SECSPERHR
 
 /* Primary channel PPS avilability dance:
  * Every good PPS sample gets us a credit of PPS_INCCOUNT points, every
@@ -206,7 +206,7 @@ typedef struct addrinfo     addrinfoT;
  * We use the same device name scheme as does the NMEA driver; since
  * GPSD supports the same links, we can select devices by a fixed name.
  */
-#define	DEVICE		"/dev/gps%u"	/* GPS serial device */
+#define	DEVICE		"/dev/gps%d"	/* GPS serial device */
 
 /* =====================================================================
  * forward declarations for transfer vector and the vector itself
@@ -238,7 +238,8 @@ struct refclock refclock_gpsdjson = {
 
 /* =====================================================================
  * our local clock unit and data
- */
+*/
+
 struct gpsd_unit;
 typedef struct gpsd_unit gpsd_unitT;
 
@@ -297,20 +298,20 @@ struct gpsd_unit {
 	/* admin stuff for sockets and device selection */
 	int         fdt;	/* current connecting socket */
 	addrinfoT * addr;	/* next address to try */
-	u_int       tickover;	/* timeout countdown */
-	u_int       tickpres;	/* timeout preset */
+	unsigned int       tickover;	/* timeout countdown */
+	unsigned int       tickpres;	/* timeout preset */
 
 	/* tallies for the various events */
-	u_int       tc_recv;	/* received known records */
-	u_int       tc_breply;	/* bad replies / parsing errors */
-	u_int       tc_nosync;	/* TPV / sample cycles w/o fix */
-	u_int       tc_ibt_recv;/* received serial time info records */
-	u_int       tc_ibt_used;/* used        --^-- */
-	u_int       tc_pps_recv;/* received PPS timing info records */
-	u_int       tc_pps_used;/* used        --^-- */
+	unsigned int       tc_recv;	/* received known records */
+	unsigned int       tc_breply;	/* bad replies / parsing errors */
+	unsigned int       tc_nosync;	/* TPV / sample cycles w/o fix */
+	unsigned int       tc_ibt_recv;/* received serial time info records */
+	unsigned int       tc_ibt_used;/* used        --^-- */
+	unsigned int       tc_pps_recv;/* received PPS timing info records */
+	unsigned int       tc_pps_used;/* used        --^-- */
 
 	/* log bloat throttle */
-	u_int       logthrottle;/* seconds to next log slot */
+	unsigned int       logthrottle;/* seconds to next log slot */
 
 	/* The parse context for the current record */
 	json_ctx    json_parse;
@@ -443,18 +444,18 @@ gpsd_init_check(void)
 	/* spool out the resolver errors */
 	for (idx = 0; idx < s_svcidx; ++idx) {
 		msyslog(LOG_WARNING,
-			"GPSD_JSON: failed to resolve '%s:%s', rc=%d (%s)",
+			"REFCLOCK: GPSD_JSON: failed to resolve '%s:%s', rc=%d (%s)",
 			s_svctab[idx][0], s_svctab[idx][1],
 			s_svcerr[idx], gai_strerror(s_svcerr[idx]));
 	}
 
 	/* check if it was fatal, or if we can proceed */
 	if (s_gpsd_addr == NULL)
-		msyslog(LOG_ERR, "%s",
-			"GPSD_JSON: failed to get socket address, giving up.");
+		msyslog(LOG_ERR,
+			"REFCLOCK: GPSD_JSON: failed to get socket address, giving up.");
 	else if (idx != 0)
 		msyslog(LOG_WARNING,
-			"GPSD_JSON: using '%s:%s' instead of '%s:%s'",
+			"REFCLOCK: GPSD_JSON: using '%s:%s' instead of '%s:%s'",
 			s_svctab[idx][0], s_svctab[idx][1],
 			s_svctab[0][0], s_svctab[0][1]);
 
@@ -507,20 +508,20 @@ gpsd_start(
 		 * practicable, we will have to read the symlink, if
 		 * any, so we can get the true device file.)
 		 */
-                if ( peer->path ) {
+                if ( peer->cfg.path ) {
                     /* use the ntp.conf path name */
-		    ret = myasprintf(&up->device, "%s", peer->path);
+		    ret = myasprintf(&up->device, "%s", peer->cfg.path);
                 } else {
                     ret = myasprintf(&up->device, DEVICE, up->unit);
                 }
 		if (-1 == ret ) {
                         /* more likely out of RAM */
-			msyslog(LOG_ERR, "%s: clock device name too long",
+			msyslog(LOG_ERR, "REFCLOCK: %s: clock device name too long",
 				up->logname);
 			goto dev_fail;
 		}
 		if (-1 == stat(up->device, &sb) || !S_ISCHR(sb.st_mode)) {
-			msyslog(LOG_ERR, "%s: '%s' is not a character device",
+			msyslog(LOG_ERR, "REFCLOCK: %s: '%s' is not a character device",
 				up->logname, up->device);
 			goto dev_fail;
 		}
@@ -550,7 +551,7 @@ gpsd_start(
 
 	/* If the daemon name lookup failed, just give up now. */
 	if (NULL == up->addr) {
-		msyslog(LOG_ERR, "%s: no GPSD socket address, giving up",
+		msyslog(LOG_ERR, "REFCLOCK: %s: no GPSD socket address, giving up",
 			up->logname);
 		goto dev_fail;
 	}
@@ -558,7 +559,7 @@ gpsd_start(
 	LOGIF(CLOCKINFO,
 	      (LOG_NOTICE, "%s: startup, device is '%s'",
 	       refclock_name(peer), up->device));
-	up->mode = MODE_OP_MODE(peer->ttl);
+	up->mode = MODE_OP_MODE(peer->cfg.ttl);
 	if (up->mode > MODE_OP_MAXVAL)
 		up->mode = 0;
 	if (unit >= 128)
@@ -601,8 +602,8 @@ gpsd_shutdown(
 	/* now check if we must close IO resources */
 	if (peer != up->pps_peer) {
 		if (-1 != pp->io.fd) {
-			DPRINTF(1, ("%s: closing clock, fd=%d\n",
-				    up->logname, pp->io.fd));
+			DPRINT(1, ("%s: closing clock, fd=%d\n",
+				   up->logname, pp->io.fd));
 			io_closeclock(&pp->io);
 			pp->io.fd = -1;
 		}
@@ -739,7 +740,7 @@ poll_secondary(
 		refclock_receive(peer);
 	} else {
 		peer->precision = PPS_PRECISION;
-		peer->flags &= ~FLAG_PPS;
+		peer->cfg.flags &= ~FLAG_PPS;
 		refclock_report(peer, CEVNT_TIMEOUT);
 	}
 }
@@ -780,15 +781,15 @@ gpsd_control(
 	if (peer == up->pps_peer) {
 		up->pps_fudge2 = dtolfp(pp->fudgetime1);
 		if ( ! (pp->sloppyclockflag & CLK_FLAG1))
-			peer->flags &= ~FLAG_PPS;
+			peer->cfg.flags &= ~FLAG_PPS;
 	} else {
 		/* save preprocessed fudge times */
 		up->pps_fudge = dtolfp(pp->fudgetime1);
 		up->ibt_fudge = dtolfp(pp->fudgetime2);
 
-		if (MODE_OP_MODE(up->mode ^ peer->ttl)) {
+		if (MODE_OP_MODE((uint32_t)up->mode ^ peer->cfg.ttl)) {
 			leave_opmode(peer, up->mode);
-			up->mode = MODE_OP_MODE(peer->ttl);
+			up->mode = MODE_OP_MODE(peer->cfg.ttl);
 			enter_opmode(peer, up->mode);
 		}
 	}
@@ -824,8 +825,8 @@ timer_primary(
 		 */
 		if (-1 != pp->io.fd) {
 			size_t rlen = strlen(s_req_version);
-			DPRINTF(2, ("%s: timer livecheck: '%s'\n",
-				    up->logname, s_req_version));
+			DPRINT(2, ("%s: timer livecheck: '%s'\n",
+				   up->logname, s_req_version));
 			log_data(peer, "send", s_req_version, rlen);
 			rc = write(pp->io.fd, s_req_version, rlen);
 			(void)rc;
@@ -864,7 +865,7 @@ timer_secondary(
 			refclock_report(peer, CEVNT_TIMEOUT);
 			pp->coderecv = pp->codeproc;
 		}
-		peer->flags &= ~FLAG_PPS;
+		peer->cfg.flags &= ~FLAG_PPS;
 	}
 }
 
@@ -896,8 +897,8 @@ enter_opmode(
 	clockprocT * const pp = peer->procptr;
 	gpsd_unitT * const up = (gpsd_unitT *)pp->unitptr;
 
-	DPRINTF(1, ("%s: enter operation mode %d\n",
-		    up->logname, MODE_OP_MODE(mode)));
+	DPRINT(1, ("%s: enter operation mode %d\n",
+		   up->logname, MODE_OP_MODE(mode)));
 
 	if (MODE_OP_MODE(mode) == MODE_OP_AUTO) {
 		up->fl_rawibt = 0;
@@ -917,8 +918,8 @@ leave_opmode(
 	clockprocT * const pp = peer->procptr;
 	gpsd_unitT * const up = (gpsd_unitT *)pp->unitptr;
 
-	DPRINTF(1, ("%s: leaving operation mode %d\n",
-		    up->logname, MODE_OP_MODE(mode)));
+	DPRINT(1, ("%s: leaving operation mode %d\n",
+		   up->logname, MODE_OP_MODE(mode)));
 
 	if (MODE_OP_MODE(mode) == MODE_OP_AUTO) {
 		up->fl_rawibt = 0;
@@ -984,7 +985,7 @@ eval_pps_secondary(
 		up->ppscount2 = min(PPS2_MAXCOUNT, (up->ppscount2 + 2));
 		if ((PPS2_MAXCOUNT == up->ppscount2) &&
 		    (pp->sloppyclockflag & CLK_FLAG1) )
-			peer->flags |= FLAG_PPS;
+			peer->cfg.flags |= FLAG_PPS;
 		/* mark time stamp as burned... */
 		up->fl_pps2 = 0;
 		++up->tc_pps_used;
@@ -1032,7 +1033,7 @@ eval_auto(
 		if ((PPS_MAXCOUNT == up->ppscount) && up->fl_rawibt) {
 			up->fl_rawibt = 0;
 			msyslog(LOG_INFO,
-				"%s: expect valid PPS from now",
+				"REFCLOCK: %s: expect valid PPS from now",
 				up->logname);
 		}
 	} else {
@@ -1040,7 +1041,7 @@ eval_auto(
 		if ((0 == up->ppscount) && !up->fl_rawibt) {
 			up->fl_rawibt = -1;
 			msyslog(LOG_WARNING,
-				"%s: use TPV alone from now",
+				"REFCLOCK: %s: use TPV alone from now",
 				up->logname);
 		}
 	}
@@ -1096,9 +1097,9 @@ strtojint(
 	hold = cp;
 	accu = 0;
 	while (isdigit(*(const unsigned char*)cp)) {
-		flags |= (accu > limit_lo);
-		accu = accu * 10 + (*(const unsigned char*)cp++ - '0');
-		flags |= (accu > limit_hi);
+	    flags |= (accu > limit_lo);
+	    accu = accu * 10 + (json_uint)(*(const unsigned char*)cp++ - '0');
+	    flags |= (accu > limit_hi);
 	}
 	/* Check for empty conversion (no digits seen). */
 	if (hold != cp)
@@ -1300,28 +1301,6 @@ json_object_lookup_int_default(
 }
 
 /* ------------------------------------------------------------------ */
-#if 0 /* currently unused */
-static double
-json_object_lookup_float(
-	const json_ctx * ctx,
-	tok_ref          tid,
-	const char     * key)
-{
-	double       ret;
-	const char * cp;
-	char       * ep;
-
-	cp = json_object_lookup_primitive(ctx, tid, key);
-	if (NULL != cp) {
-		ret = strtod(cp, &ep);
-		if (cp != ep && '\0' == *ep)
-			return ret;
-	} else {
-		errno = EINVAL;
-	}
-	return 0.0;
-}
-#endif
 
 static double
 json_object_lookup_float_default(
@@ -1428,8 +1407,8 @@ process_watch(
 		up->fl_watch = -1;
 	else
 		up->fl_watch = 0;
-	DPRINTF(2, ("%s: process_watch, enabled=%d\n",
-		    up->logname, (up->fl_watch & 1)));
+	DPRINT(2, ("%s: process_watch, enabled=%d\n",
+		   up->logname, (up->fl_watch & 1)));
 }
 
 /* ------------------------------------------------------------------ */
@@ -1464,7 +1443,7 @@ process_version(
 	if (0 == errno) {
 		if ( ! up->fl_vers)
 			msyslog(LOG_INFO,
-				"%s: GPSD revision=%s release=%s protocol=%u.%u",
+				"REFCLOCK: %s: GPSD revision=%s release=%s protocol=%u.%u",
 				up->logname, revision, release,
 				pvhi, pvlo);
 		up->proto_version = PROTO_VERSION(pvhi, pvlo);
@@ -1472,7 +1451,7 @@ process_version(
 	} else {
 		if (syslogok(pp, up))
 			msyslog(LOG_INFO,
-				"%s: could not evaluate version data",
+				"REFCLOCK: %s: could not evaluate version data",
 				up->logname);
 		return;
 	}
@@ -1513,7 +1492,7 @@ process_version(
 		 * resulting data timeout will take care of the
 		 * connection!
 		 */
-		msyslog(LOG_ERR, "%s: failed to write watch request (%m)",
+		msyslog(LOG_ERR, "REFCLOCK: %s: failed to write watch request (%m)",
 			up->logname);
 	}
 }
@@ -1562,12 +1541,12 @@ process_tpv(
 		save_ltc(pp, gps_time);
 		/* now parse the time string */
 		if (convert_ascii_time(&up->ibt_stamp, gps_time)) {
-			DPRINTF(2, ("%s: process_tpv, stamp='%s',"
-				    " recvt='%s' mode=%u\n",
-				    up->logname,
-				    gmprettydate(up->ibt_stamp),
-				    gmprettydate(up->ibt_recvt),
-				    gps_mode));
+			DPRINT(2, ("%s: process_tpv, stamp='%s',"
+				   " recvt='%s' mode=%d\n",
+				   up->logname,
+				   prettydate(up->ibt_stamp),
+				   prettydate(up->ibt_recvt),
+				   gps_mode));
 
 			/* have to use local receive time as substitute
 			 * for the real receive time: TPV does not tell
@@ -1662,20 +1641,20 @@ process_pps(
 	setlfpfrac(up->pps_stamp, 0);
 
 	if (NULL != up->pps_peer)
-		save_ltc(up->pps_peer->procptr, gmprettydate(up->pps_stamp2));
-	DPRINTF(2, ("%s: PPS record processed,"
-		    " stamp='%s', recvt='%s'\n",
-		    up->logname,
-		    gmprettydate(up->pps_stamp2),
-		    gmprettydate(up->pps_recvt2)));
+		save_ltc(up->pps_peer->procptr, prettydate(up->pps_stamp2));
+	DPRINT(2, ("%s: PPS record processed,"
+		   " stamp='%s', recvt='%s'\n",
+		   up->logname,
+		   prettydate(up->pps_stamp2),
+		   prettydate(up->pps_recvt2)));
 	
 	up->fl_pps  = (0 != (pp->sloppyclockflag & CLK_FLAG2)) - 1;
 	up->fl_pps2 = -1;
 	return;
 
   fail:
-	DPRINTF(1, ("%s: PPS record processing FAILED\n",
-		    up->logname));
+	DPRINT(1, ("%s: PPS record processing FAILED\n",
+		   up->logname));
 	++up->tc_breply;
 }
 
@@ -1709,17 +1688,17 @@ process_toff(
 	up->ibt_local = *rtime;
 	up->fl_ibt    = -1;
 
-	save_ltc(pp, gmprettydate(up->ibt_stamp));
-	DPRINTF(2, ("%s: TOFF record processed,"
-		    " stamp='%s', recvt='%s'\n",
-		    up->logname,
-		    gmprettydate(up->ibt_stamp),
-		    gmprettydate(up->ibt_recvt)));
+	save_ltc(pp, prettydate(up->ibt_stamp));
+	DPRINT(2, ("%s: TOFF record processed,"
+		   " stamp='%s', recvt='%s'\n",
+		   up->logname,
+		   prettydate(up->ibt_stamp),
+		   prettydate(up->ibt_recvt)));
 	return;
 
   fail:
-	DPRINTF(1, ("%s: TOFF record processing FAILED\n",
-		    up->logname));
+	DPRINT(1, ("%s: TOFF record processing FAILED\n",
+		   up->logname));
 	++up->tc_breply;
 }
 
@@ -1735,9 +1714,9 @@ gpsd_parse(
 
 	const char * clsid;
 
-        DPRINTF(2, ("%s: gpsd_parse: time %s '%.*s'\n",
-                    up->logname, ulfptoa(*rtime, 6),
-		    up->buflen, up->buffer));
+        DPRINT(2, ("%s: gpsd_parse: time %s '%.*s'\n",
+		   up->logname, ulfptoa(*rtime, 6),
+		   up->buflen, up->buffer));
 
 	/* See if we can grab anything potentially useful. JSMN does not
 	 * need a trailing NUL, but it needs the number of bytes to
@@ -1818,11 +1797,11 @@ gpsd_stop_socket(
 	if (-1 != pp->io.fd) {
 		if (syslogok(pp, up))
 			msyslog(LOG_INFO,
-				"%s: closing socket to GPSD, fd=%d",
+				"REFCLOCK: %s: closing socket to GPSD, fd=%d",
 				up->logname, pp->io.fd);
 		else
-			DPRINTF(1, ("%s: closing socket to GPSD, fd=%d\n",
-				    up->logname, pp->io.fd));
+			DPRINT(1, ("%s: closing socket to GPSD, fd=%d\n",
+				   up->logname, pp->io.fd));
 		io_closeclock(&pp->io);
 		pp->io.fd = -1;
 	}
@@ -1858,7 +1837,7 @@ gpsd_init_socket(
 	if (-1 == up->fdt) {
 		if (syslogok(pp, up))
 			msyslog(LOG_ERR,
-				"%s: cannot create GPSD socket: %m",
+				"REFCLOCK: %s: cannot create GPSD socket: %m",
 				up->logname);
 		goto no_socket;
 	}
@@ -1871,7 +1850,7 @@ gpsd_init_socket(
 	if (-1 == rc) {
 		if (syslogok(pp, up))
 			msyslog(LOG_ERR,
-				"%s: cannot set GPSD socket to non-blocking: %m",
+				"RECLOCK: %s: cannot set GPSD socket to non-blocking: %m",
 				up->logname);
 		goto no_socket;
 	}
@@ -1887,7 +1866,7 @@ gpsd_init_socket(
 	if (-1 == rc) {
 		if (syslogok(pp, up))
 			msyslog(LOG_INFO,
-				"%s: cannot disable TCP nagle: %m",
+				"REFCLOCK: %s: cannot disable TCP nagle: %m",
 				up->logname);
 	}
 
@@ -1897,14 +1876,14 @@ gpsd_init_socket(
 	rc = connect(up->fdt, ai->ai_addr, ai->ai_addrlen);
 	if (-1 == rc) {
 		if (errno == EINPROGRESS) {
-			DPRINTF(1, ("%s: async connect pending, fd=%d\n",
-				    up->logname, up->fdt));
+			DPRINT(1, ("%s: async connect pending, fd=%d\n",
+				   up->logname, up->fdt));
 			return;
 		}
 
 		if (syslogok(pp, up))
 			msyslog(LOG_ERR,
-				"%s: cannot connect GPSD socket: %m",
+				"REFCLOCK: %s: cannot connect GPSD socket: %m",
 				up->logname);
 		goto no_socket;
 	}
@@ -1914,15 +1893,15 @@ gpsd_init_socket(
 	 * version string and apply the watch command later on, but we
 	 * might as well get the show on the road now.
 	 */
-	DPRINTF(1, ("%s: new socket connection, fd=%d\n",
-		    up->logname, up->fdt));
+	DPRINT(1, ("%s: new socket connection, fd=%d\n",
+		   up->logname, up->fdt));
 
 	pp->io.fd = up->fdt;
 	up->fdt   = -1;
 	if (0 == io_addclock(&pp->io)) {
 		if (syslogok(pp, up))
 			msyslog(LOG_ERR,
-				"%s: failed to register with I/O engine",
+				"REFCLOCK: %s: failed to register with I/O engine",
 				up->logname);
 		goto no_socket;
 	}
@@ -1956,8 +1935,8 @@ gpsd_test_socket(
 	 * socket for writeability. Use the 'poll()' API if available
 	 * and 'select()' otherwise.
 	 */
-	DPRINTF(2, ("%s: check connect, fd=%d\n",
-		    up->logname, up->fdt));
+	DPRINT(2, ("%s: check connect, fd=%d\n",
+		   up->logname, up->fdt));
 
 	{
 		struct timespec tout;
@@ -1985,17 +1964,17 @@ gpsd_test_socket(
 		errtxt = strerror(ec);
 		if (syslogok(pp, up))
 			msyslog(LOG_ERR,
-				"%s: async connect to GPSD failed,"
+				"REFCLOCK: %s: async connect to GPSD failed,"
 				" fd=%d, ec=%d(%s)",
 				up->logname, up->fdt, ec, errtxt);
 		else
-			DPRINTF(1, ("%s: async connect to GPSD failed,"
-				" fd=%d, ec=%d(%s)\n",
-				    up->logname, up->fdt, ec, errtxt));
+			DPRINT(1, ("%s: async connect to GPSD failed,"
+				   " fd=%d, ec=%d(%s)\n",
+				   up->logname, up->fdt, ec, errtxt));
 		goto no_socket;
 	} else {
-		DPRINTF(1, ("%s: async connect to GPSD succeeded, fd=%d\n",
-			    up->logname, up->fdt));
+		DPRINT(1, ("%s: async connect to GPSD succeeded, fd=%d\n",
+			   up->logname, up->fdt));
 	}
 
 	/* swap socket FDs, and make sure the clock was added */
@@ -2004,7 +1983,7 @@ gpsd_test_socket(
 	if (0 == io_addclock(&pp->io)) {
 		if (syslogok(pp, up))
 			msyslog(LOG_ERR,
-				"%s: failed to register with I/O engine",
+				"REFCLOCK: %s: failed to register with I/O engine",
 				up->logname);
 		goto no_socket;
 	}
@@ -2012,8 +1991,8 @@ gpsd_test_socket(
 
   no_socket:
 	if (-1 != up->fdt) {
-		DPRINTF(1, ("%s: closing socket, fd=%d\n",
-			    up->logname, up->fdt));
+		DPRINT(1, ("%s: closing socket, fd=%d\n",
+			   up->logname, up->fdt));
 		close(up->fdt);
 	}
 	up->fdt      = -1;
@@ -2050,7 +2029,7 @@ convert_ascii_time(
 	char           *ep;
 	struct tm       gd;
 	struct timespec ts;
-	uint32_t        dw;
+	long   dw;
 
 	/* Use 'strptime' to take the brunt of the work, then parse
 	 * the fractional part manually, starting with a digit weight of
@@ -2061,10 +2040,10 @@ convert_ascii_time(
 	if (NULL == ep)
 		return false; /* could not parse the mandatory stuff! */
 	if (*ep == '.') {
-		dw = 100000000u;
+		dw = 100000000;
 		while (isdigit(*(unsigned char*)++ep)) {
-			ts.tv_nsec += (*(unsigned char*)ep - '0') * dw;
-			dw /= 10u;
+		    ts.tv_nsec += (long)(*(unsigned char*)ep - '0') * dw;
+		    dw /= 10;
 		}
 	}
 	if (ep[0] != 'Z' || ep[1] != '\0')
@@ -2095,7 +2074,7 @@ save_ltc(
 	len = (tc) ? strlen(tc) : 0;
 	if (len >= sizeof(pp->a_lastcode))
 		len = sizeof(pp->a_lastcode) - 1;
-	pp->lencode = (u_short)len;
+	pp->lencode = (unsigned short)len;
 	memcpy(pp->a_lastcode, tc, len);
 	pp->a_lastcode[len] = '\0';
 }
@@ -2158,7 +2137,7 @@ log_data(
 	clockprocT * const pp = peer->procptr;
 	gpsd_unitT * const up = (gpsd_unitT *)pp->unitptr;
 
-	if (debug > 1) {
+	if (debug > 1) { /* SPECIAL DEBUG */
 		const char *sptr = buf;
 		const char *stop = buf + len;
 		char       *dptr = s_lbuf;
