@@ -57,16 +57,6 @@
 #define STRATUM 	5	/* default stratum */
 #define DISPERSION	.01	/* default dispersion (10 ms) */
 
-/*
- * Imported from the timer module
- */
-extern u_long current_time;
-
-/*
- * Imported from ntp_proto
- */
-extern int8_t sys_precision;
-
 /*
  * Function prototypes
  */
@@ -76,7 +66,7 @@ static	void	local_poll	(int, struct peer *);
 /*
  * Local variables
  */
-static	u_long poll_time;	/* last time polled */
+static	unsigned long poll_time;	/* last time polled */
 
 /*
  * Transfer vector
