@@ -24,6 +24,10 @@
  * use as backup when neither a radio clock nor connectivity to Internet
  * time servers is available.
  *
+ * WARNING: The ACTS mode of this driver depends on the system clock
+ * for year disambiguation.  It will thus not be usable for recovery
+ * if the system clock is trashed.
+ *
  * This driver requires a modem with a Hayes-compatible command set
  * and control over the modem data terminal ready (DTR) control
  * line. The default modem setup string is hard-coded in the driver
@@ -89,7 +93,7 @@
  *
  * US Naval Observatory (USNO)
  *
- * Phone: (202) 762-1594 (Washington, DC); (719) 567-6742 (Boulder, CO)
+ * Phone: (202) 762-1594 (Washington, DC); (719) 567-6743 (Colorado Springs, CO)
  *
  * Data Format (two lines, repeating at one-second intervals)
  *
@@ -346,7 +350,7 @@ modem_receive(
 			if (*tptr == '*' || *tptr == '#') {
 				up->tstamp = pp->lastrec;
 				if (write(pp->io.fd, tptr, 1) < 0)
-					msyslog(LOG_ERR, "modem: write echo fails %m");
+					msyslog(LOG_ERR, "REFCLOCK: modem: write echo fails %m");
 			}
 		}
 	}
@@ -367,7 +371,7 @@ modem_message(
 	char	tbuf[BMAX], *cp;
 	int		dtr = TIOCM_DTR;
 
-	DPRINTF(1, ("modem: %d %s\n", (int)strlen(msg), msg));
+	DPRINT(1, ("modem: %d %s\n", (int)strlen(msg), msg));
 
 	/*
 	 * What to do depends on the state and the first token in the
@@ -408,10 +412,10 @@ modem_message(
 		mprintf_event(PEVNT_CLOCK, peer, "DIAL #%d %s",
 			      up->retry, sys_phone[up->retry]);
 		if (ioctl(pp->io.fd, TIOCMBIS, &dtr) < 0)
-			msyslog(LOG_ERR, "modem: ioctl(TIOCMBIS) failed: %m");
+			msyslog(LOG_ERR, "REFCLOCK: modem: ioctl(TIOCMBIS) failed: %m");
 		if (write(pp->io.fd, sys_phone[up->retry],
 		    strlen(sys_phone[up->retry])) < 0)
-			msyslog(LOG_ERR, "modem: write DIAL fails %m");
+			msyslog(LOG_ERR, "REFCLOCK: modem: write DIAL fails %m");
 		IGNORE(write(pp->io.fd, "\r", 1));
 		up->retry++;
 		up->state = S_CONNECT;
@@ -446,6 +450,10 @@ modem_message(
 		else
 			modem_timeout(peer, S_MSG);
 		return;
+
+        default:
+                /* huh? */
+                break;
 	}
 
 	/*
@@ -502,10 +510,10 @@ modem_timeout(
 				report_event(PEVNT_CLOCK, peer, "modem: port busy");
 				return;
 			}
-			snprintf(pidbuf, sizeof(pidbuf), "%d\n",
-			    (u_int)getpid());
+			snprintf(pidbuf, sizeof(pidbuf), "%u\n",
+			    (unsigned int)getpid());
 			if (write(fd, pidbuf, strlen(pidbuf)) < 0)
-				msyslog(LOG_ERR, "modem: write lock fails %m");
+				msyslog(LOG_ERR, "REFCLOCK: modem: write lock fails %m");
 			close(fd);
 		}
 
@@ -513,16 +521,16 @@ modem_timeout(
 		 * Open the device in raw mode and link the I/O.
 		 */
 		snprintf(device, sizeof(device), DEVICE, up->unit);
-		fd = refclock_open(peer->path ? peer->path : device,
-				   peer->baud ? peer->baud : SPEED232,
+		fd = refclock_open(peer->cfg.path ? peer->cfg.path : device,
+				   peer->cfg.baud ? peer->cfg.baud : SPEED232,
 				   LDISC_ACTS | LDISC_RAW | LDISC_REMOTE);
 		if (fd < 0) {
-			msyslog(LOG_ERR, "modem: open fails %m");
+			msyslog(LOG_ERR, "REFCLOCK: modem: open fails %m");
 			return;
 		}
 		pp->io.fd = fd;
 		if (!io_addclock(&pp->io)) {
-			msyslog(LOG_ERR, "modem: addclock fails");
+			msyslog(LOG_ERR, "REFCLOCK: modem: addclock fails");
 			close(fd);
 			pp->io.fd = -1;
 			return;
@@ -536,7 +544,7 @@ modem_timeout(
 		 */
 		if (sys_phone[up->retry] == NULL) {
 			if (write(pp->io.fd, "T", 1) < 0)
-				msyslog(LOG_ERR, "modem: write T fails %m");
+				msyslog(LOG_ERR, "REFCLOCK: modem: write T fails %m");
 			up->state = S_MSG;
 			up->timer = TIMECODE;
 			return;
@@ -550,7 +558,7 @@ modem_timeout(
 			      modem_setup);
 		rc = write(pp->io.fd, modem_setup, strlen(modem_setup));
 		if (rc < 0)
-			msyslog(LOG_ERR, "modem: write SETUP fails %m");
+			msyslog(LOG_ERR, "REFCLOCK: modem: write SETUP fails %m");
 		IGNORE(write(pp->io.fd, "\r", 1));
 		up->state = S_SETUP;
 		up->timer = SETUP;
@@ -584,6 +592,10 @@ modem_timeout(
 			refclock_receive(peer);
 		}
 		break;
+
+        default:
+                /* huh? */
+                break;
 	}
 	modem_close(peer);
 }
@@ -612,7 +624,7 @@ modem_close(
 		report_event(PEVNT_CLOCK, peer, "close");
 		dtr = TIOCM_DTR;
 		if (ioctl(pp->io.fd, TIOCMBIC, &dtr) < 0)
-			msyslog(LOG_ERR, "modem: ioctl(TIOCMBIC) failed: %m");
+			msyslog(LOG_ERR, "REFCLOCK: modem: ioctl(TIOCMBIC) failed: %m");
 		io_closeclock(&pp->io);
 		pp->io.fd = -1;
 	}
@@ -654,7 +666,7 @@ modem_poll(
 	 */
 	pp = peer->procptr;
 	up = pp->unitptr;
-	switch (peer->ttl) {
+	switch (peer->cfg.ttl) {
 
 	/*
 	 * In manual mode the calling program is activated by the ntpq
@@ -680,6 +692,10 @@ modem_poll(
 			return;
 
 		break;
+
+        default:
+                /* huh? */
+                break;
 	}
 	pp->polls++;
 	if (S_IDLE == up->state) {
@@ -736,11 +752,11 @@ modem_timecode(
 	struct refclockproc *pp;
 	int	day;		/* day of the month */
 	int	month;		/* month of the year */
-	u_long	mjd;		/* Modified Julian Day */
+	unsigned long	mjd;	/* Modified Julian Day */
 	double	dut1;		/* DUT adjustment */
 
-	u_int	dst;		/* ACTS daylight/standard time */
-	u_int	leap;		/* ACTS leap indicator */
+	unsigned int	dst;		/* ACTS daylight/standard time */
+	unsigned int	leap;		/* ACTS leap indicator */
 	double	msADV;		/* ACTS transmit advance (ms) */
 	char	utc[10];	/* ACTS timescale */
 	char	flag;		/* ACTS on-time character (* or #) */
@@ -780,7 +796,7 @@ modem_timecode(
 	 */
 	case LENACTS:
 		if (sscanf(str,
-		    "%5ld %2d-%2d-%2d %2d:%2d:%2d %2d %1d %3lf %5lf %9s %c",
+		    "%5lu %2d-%2d-%2d %2d:%2d:%2d %2u %1u %3lf %5lf %9s %c",
 		    &mjd, &pp->year, &month, &day, &pp->hour,
 		    &pp->minute, &pp->second, &dst, &leap, &dut1,
 		    &msADV, utc, &flag) != 13) {
@@ -805,7 +821,7 @@ modem_timecode(
 	 * USNO format: "jjjjj nnn hhmmss UTC"
 	 */
 	case LENUSNO:
-		if (sscanf(str, "%5ld %3d %2d%2d%2d %3s",
+		if (sscanf(str, "%5lu %3d %2d%2d%2d %3s",
 		    &mjd, &pp->day, &pp->hour, &pp->minute,
 		    &pp->second, utc) != 6) {
 			refclock_report(peer, CEVNT_BADREPLY);
@@ -828,7 +844,7 @@ modem_timecode(
 	 */
 	case LENPTB:
 		if (sscanf(str,
-		    "%*4d-%*2d-%*2d %*2d:%*2d:%2d %*5c%*12c%4d%2d%2d%2d%2d%5ld%2lf%c%2d%3lf%*15c%c",
+		    "%*4d-%*2d-%*2d %*2d:%*2d:%2d %*5c%*12c%4d%2d%2d%2d%2d%5lu%2lf%c%2d%3lf%*15c%c",
 		    &pp->second, &pp->year, &month, &day, &pp->hour,
 		    &pp->minute, &mjd, &dut1, &leapdir, &leapmonth,
 		    &msADV, &flag) != 12) {
