@@ -22,11 +22,17 @@
 #include "ntp_io.h"
 #include "ntp_refclock.h"
 #include "ntp_stdlib.h"
+#include "timespecops.h"
+#include "ntp_calendar.h"	/* for SECSPERHR */
 
 #define NAME		"NEOCLOCK"
 #define DESCRIPTION	"NeoClock4X"
 
 /*
+ * WARNING: This driver depends on the system clock for year
+ * disambiguation.  It will thus not be usable for recovery if the
+ * system clock is trashed.
+ *
  * If you want the driver for whatever reason to not use
  * the TX line to send anything to your NeoClock4X
  * device you must tell the NTP refclock driver which
@@ -73,7 +79,7 @@
 struct neoclock4x_unit {
   l_fp	laststamp;	/* last receive timestamp */
   short	unit;		/* NTP refclock unit number */
-  u_long polled;	/* flag to detect noreplies */
+  unsigned long polled;	/* flag to detect noreplies */
   char	leap_status;	/* leap second flag */
   bool	recvnow;
 
@@ -140,8 +146,8 @@ neoclock4x_start(int unit,
   /* LDISC_STD, LDISC_RAW
    * Open serial port. Use CLK line discipline, if available.
    */
-  fd = refclock_open(peer->path ? peer->path : dev,
-		     peer->baud ? peer->baud : B2400,
+  fd = refclock_open(peer->cfg.path ? peer->cfg.path : dev,
+		     peer->cfg.baud ? peer->cfg.baud : B2400,
 		     LDISC_STD);
   if(fd <= 0)
     {
@@ -152,7 +158,7 @@ neoclock4x_start(int unit,
 #if 1
   if(tcgetattr(fd, &termsettings) < 0)
     {
-      msyslog(LOG_CRIT, "NeoClock4X(%d): (tcgetattr) can't query serial port settings: %m", unit);
+      msyslog(LOG_CRIT, "REFCLOCK: NeoClock4X(%d): (tcgetattr) can't query serial port settings: %m", unit);
       (void) close(fd);
       return false;
     }
@@ -161,12 +167,12 @@ neoclock4x_start(int unit,
   termsettings.c_iflag = IGNBRK | IGNPAR | ICRNL;
   termsettings.c_oflag = 0;
   termsettings.c_cflag = CS8 | CSTOPB | CLOCAL | CREAD;
-  (void)cfsetispeed(&termsettings, (u_int)B2400);
-  (void)cfsetospeed(&termsettings, (u_int)B2400);
+  (void)cfsetispeed(&termsettings, (unsigned int)B2400);
+  (void)cfsetospeed(&termsettings, (unsigned int)B2400);
 
   if(tcsetattr(fd, TCSANOW, &termsettings) < 0)
     {
-      msyslog(LOG_CRIT, "NeoClock4X(%d): (tcsetattr) can't set serial port 2400 8N2: %m", unit);
+      msyslog(LOG_CRIT, "REFCLOCK: NeoClock4X(%d): (tcsetattr) can't set serial port 2400 8N2: %m", unit);
       (void) close(fd);
       return false;
     }
@@ -174,7 +180,7 @@ neoclock4x_start(int unit,
 #else
   if(tcgetattr(fd, &termsettings) < 0)
     {
-      msyslog(LOG_CRIT, "NeoClock4X(%d): (tcgetattr) can't query serial port settings: %m", unit);
+      msyslog(LOG_CRIT, "REFCLOCK: NeoClock4X(%d): (tcgetattr) can't query serial port settings: %m", unit);
       (void) close(fd);
       return false;
     }
@@ -187,7 +193,7 @@ neoclock4x_start(int unit,
 
   if(tcsetattr(fd, TCSANOW, &termsettings) < 0)
     {
-      msyslog(LOG_CRIT, "NeoClock4X(%d): (tcsetattr) can't set serial port 2400 8N2: %m", unit);
+      msyslog(LOG_CRIT, "REFCLOCK: NeoClock4X(%d): (tcsetattr) can't set serial port 2400 8N2: %m", unit);
       (void) close(fd);
       return false;
     }
@@ -196,9 +202,9 @@ neoclock4x_start(int unit,
 #if defined(TIOCMSET) && (defined(TIOCM_RTS) || defined(CIOCM_RTS))
   /* turn on RTS, and DTR for power supply */
   /* NeoClock4x is powered from serial line */
-  if(ioctl(fd, TIOCMGET, (caddr_t)&sl232) == -1)
+  if(ioctl(fd, TIOCMGET, (void *)&sl232) == -1)
     {
-      msyslog(LOG_CRIT, "NeoClock4X(%d): can't query RTS/DTR state: %m", unit);
+      msyslog(LOG_CRIT, "REFCLOCK: NeoClock4X(%d): can't query RTS/DTR state: %m", unit);
       (void) close(fd);
       return false;
     }
@@ -207,14 +213,14 @@ neoclock4x_start(int unit,
 #else
   sl232 = sl232 | CIOCM_DTR | CIOCM_RTS;	/* turn on RTS, and DTR for power supply */
 #endif
-  if(ioctl(fd, TIOCMSET, (caddr_t)&sl232) == -1)
+  if(ioctl(fd, TIOCMSET, (void *)&sl232) == -1)
     {
-      msyslog(LOG_CRIT, "NeoClock4X(%d): can't set RTS/DTR to power neoclock4x: %m", unit);
+      msyslog(LOG_CRIT, "REFCLOCK: NeoClock4X(%d): can't set RTS/DTR to power neoclock4x: %m", unit);
       (void) close(fd);
       return false;
     }
 #else
-  msyslog(LOG_EMERG, "NeoClock4X(%d): don't know how to set DTR/RTS to power NeoClock4X with this OS!",
+  msyslog(LOG_EMERG, "REFCLOCK: NeoClock4X(%d): don't know how to set DTR/RTS to power NeoClock4X with this OS!",
 	  unit);
   (void) close(fd);
   return false;
@@ -223,7 +229,7 @@ neoclock4x_start(int unit,
   up = (struct neoclock4x_unit *) emalloc(sizeof(struct neoclock4x_unit));
   if(!(up))
     {
-      msyslog(LOG_ERR, "NeoClock4X(%d): can't allocate memory for: %m",unit);
+      msyslog(LOG_ERR, "REFCLOCK: NeoClock4X(%d): can't allocate memory for: %m",unit);
       (void) close(fd);
       return false;
     }
@@ -278,7 +284,7 @@ neoclock4x_start(int unit,
 	  sizeof(up->firmware));
   up->firmwaretag = 'A';
 #else
-  msyslog(LOG_EMERG, "NeoClock4X(%d): unknown firmware defined at compile time for NeoClock4X",
+  msyslog(LOG_EMERG, "REFCLOCK: NeoClock4X(%d): unknown firmware defined at compile time for NeoClock4X",
 	  unit);
   (void) close(fd);
   pp->io.fd = -1;
@@ -290,7 +296,7 @@ neoclock4x_start(int unit,
   for(tries=0; tries < 5; tries++)
     {
       NLOG(NLOG_CLOCKINFO)
-	msyslog(LOG_INFO, "NeoClock4X(%d): checking NeoClock4X firmware version (%d/5)", unit, tries);
+	msyslog(LOG_INFO, "REFCLOCK: NeoClock4X(%d): checking NeoClock4X firmware version (%d/5)", unit, tries);
       /* wait 3 seconds for receiver to power up */
       sleep(3);
       if(neol_query_firmware(pp->io.fd, up->unit, up->firmware, sizeof(up->firmware)))
@@ -312,7 +318,7 @@ neoclock4x_start(int unit,
 
   if(!io_addclock(&pp->io))
     {
-      msyslog(LOG_ERR, "NeoClock4X(%d): error add peer to ntpd: %m", unit);
+      msyslog(LOG_ERR, "REFCLOCK: NeoClock4X(%d): error add peer to ntpd: %m", unit);
       (void) close(fd);
       pp->io.fd = -1;
       free(pp->unitptr);
@@ -321,7 +327,7 @@ neoclock4x_start(int unit,
     }
 
   NLOG(NLOG_CLOCKINFO)
-    msyslog(LOG_INFO, "NeoClock4X(%d): receiver setup successful done", unit);
+    msyslog(LOG_INFO, "REFCLOCK: NeoClock4X(%d): receiver setup successful done", unit);
 
   return true;
 }
@@ -347,9 +353,9 @@ neoclock4x_shutdown(int unit,
 #if defined(TIOCMSET) && (defined(TIOCM_RTS) || defined(CIOCM_RTS))
                   /* turn on RTS, and DTR for power supply */
                   /* NeoClock4x is powered from serial line */
-                  if(ioctl(pp->io.fd, TIOCMGET, (caddr_t)&sl232) == -1)
+                  if(ioctl(pp->io.fd, TIOCMGET, (void *)&sl232) == -1)
                     {
-                      msyslog(LOG_CRIT, "NeoClock4X(%d): can't query RTS/DTR state: %m",
+                      msyslog(LOG_CRIT, "REFCLOCK: NeoClock4X(%d): can't query RTS/DTR state: %m",
                               unit);
                     }
 #ifdef TIOCM_RTS
@@ -359,9 +365,9 @@ neoclock4x_shutdown(int unit,
                   /* turn on RTS, and DTR for power supply */
                   sl232 &= ~(CIOCM_DTR | CIOCM_RTS);
 #endif
-                  if(ioctl(pp->io.fd, TIOCMSET, (caddr_t)&sl232) == -1)
+                  if(ioctl(pp->io.fd, TIOCMSET, (void *)&sl232) == -1)
                     {
-                      msyslog(LOG_CRIT, "NeoClock4X(%d): can't set RTS/DTR to power neoclock4x: %m",
+                      msyslog(LOG_CRIT, "REFCLOCK: NeoClock4X(%d): can't set RTS/DTR to power neoclock4x: %m",
                               unit);
                     }
 #endif
@@ -373,10 +379,10 @@ neoclock4x_shutdown(int unit,
         }
     }
 
-  msyslog(LOG_ERR, "NeoClock4X(%d): shutdown", unit);
+  msyslog(LOG_ERR, "REFCLOCK: NeoClock4X(%d): shutdown", unit);
 
   NLOG(NLOG_CLOCKINFO)
-    msyslog(LOG_INFO, "NeoClock4X(%d): receiver shutdown done", unit);
+    msyslog(LOG_INFO, "REFCLOCK: NeoClock4X(%d): receiver shutdown done", unit);
 }
 
 static void
@@ -411,7 +417,7 @@ neoclock4x_receive(struct recvbuf *rbufp)
   if(NEOCLOCK4X_TIMECODELEN != pp->lencode)
     {
       NLOG(NLOG_CLOCKEVENT)
-	msyslog(LOG_WARNING, "NeoClock4X(%d): received data has invalid length, expected %d bytes, received %d bytes: %s",
+	msyslog(LOG_WARNING, "REFCLOCK: NeoClock4X(%d): received data has invalid length, expected %d bytes, received %d bytes: %s",
 		up->unit, NEOCLOCK4X_TIMECODELEN, pp->lencode, pp->a_lastcode);
       refclock_report(peer, CEVNT_BADREPLY);
       return;
@@ -428,7 +434,7 @@ neoclock4x_receive(struct recvbuf *rbufp)
   if(recv_chksum != calc_chksum)
     {
       NLOG(NLOG_CLOCKEVENT)
-	msyslog(LOG_WARNING, "NeoClock4X(%d): received data has invalid chksum: %s",
+	msyslog(LOG_WARNING, "REFCLOCK: NeoClock4X(%d): received data has invalid chksum: %s",
 		up->unit, pp->a_lastcode);
       refclock_report(peer, CEVNT_BADREPLY);
       return;
@@ -444,7 +450,7 @@ neoclock4x_receive(struct recvbuf *rbufp)
       if('I' != up->quarzstatus)
 	{
 	  NLOG(NLOG_CLOCKEVENT)
-	    msyslog(LOG_NOTICE, "NeoClock4X(%d): quartz clock is not initialized: %s",
+	    msyslog(LOG_NOTICE, "REFCLOCK: NeoClock4X(%d): quartz clock is not initialized: %s",
 		    up->unit, pp->a_lastcode);
 	  pp->leap = LEAP_NOTINSYNC;
 	  refclock_report(peer, CEVNT_BADDATE);
@@ -454,7 +460,7 @@ neoclock4x_receive(struct recvbuf *rbufp)
   if('I' != up->quarzstatus)
     {
       NLOG(NLOG_CLOCKEVENT)
-	msyslog(LOG_NOTICE, "NeoClock4X(%d): using uninitialized quartz clock for time synchronization: %s",
+	msyslog(LOG_NOTICE, "REFCLOCK: NeoClock4X(%d): using uninitialized quartz clock for time synchronization: %s",
 		up->unit, pp->a_lastcode);
     }
 
@@ -481,7 +487,7 @@ neoclock4x_receive(struct recvbuf *rbufp)
   /* this should only used when first install is done */
   if(pp->sloppyclockflag & CLK_FLAG4)
     {
-      msyslog(LOG_DEBUG, "NeoClock4X(%d): received data: %s",
+      msyslog(LOG_DEBUG, "REFCLOCK: NeoClock4X(%d): received data: %s",
 	      up->unit, pp->a_lastcode);
     }
 
@@ -517,7 +523,7 @@ neoclock4x_receive(struct recvbuf *rbufp)
      (pp->year < 0) || (pp->year > 99)) {
     /* Data out of range. */
     NLOG(NLOG_CLOCKEVENT)
-      msyslog(LOG_WARNING, "NeoClock4X(%d): date/time out of range: %s",
+      msyslog(LOG_WARNING, "REFCLOCK: NeoClock4X(%d): date/time out of range: %s",
 	      up->unit, pp->a_lastcode);
     refclock_report(peer, CEVNT_BADDATE);
     return;
@@ -537,10 +543,10 @@ neoclock4x_receive(struct recvbuf *rbufp)
 
   /* adjust NeoClock4X local time to UTC */
   calc_utc = neol_mktime(pp->year, month, day, pp->hour, pp->minute, pp->second);
-  calc_utc -= 3600;
+  calc_utc -= SECSPERHR;
   /* adjust NeoClock4X daylight saving time if needed */
   if('S' == up->dststatus)
-    calc_utc -= 3600;
+    calc_utc -= SECSPERHR;
   neol_localtime(calc_utc, &pp->year, &month, &day, &pp->hour, &pp->minute, &pp->second);
 
   /*
@@ -551,7 +557,7 @@ neoclock4x_receive(struct recvbuf *rbufp)
 
   if(pp->sloppyclockflag & CLK_FLAG4)
     {
-      msyslog(LOG_DEBUG, "NeoClock4X(%d): calculated UTC date/time: %04d-%02d-%02d %02d:%02d:%02d.%03ld",
+      msyslog(LOG_DEBUG, "REFCLOCK: NeoClock4X(%d): calculated UTC date/time: %04d-%02d-%02d %02d:%02d:%02d.%03ld",
 	      up->unit,
 	      pp->year, month, day,
 	      pp->hour, pp->minute, pp->second,
@@ -570,7 +576,7 @@ neoclock4x_receive(struct recvbuf *rbufp)
   if(!refclock_process(pp))
     {
       NLOG(NLOG_CLOCKEVENT)
-	msyslog(LOG_WARNING, "NeoClock4X(%d): refclock_process failed!", up->unit);
+	msyslog(LOG_WARNING, "REFCLOCK: NeoClock4X(%d): refclock_process failed!", up->unit);
       refclock_report(peer, CEVNT_FAULT);
       return;
     }
@@ -609,21 +615,21 @@ neoclock4x_control(int unit,
 
   if(NULL == peer)
     {
-      msyslog(LOG_ERR, "NeoClock4X(%d): control: unit invalid/inactive", unit);
+      msyslog(LOG_ERR, "REFCLOCK: NeoClock4X(%d): control: unit invalid/inactive", unit);
       return;
     }
 
   pp = peer->procptr;
   if(NULL == pp)
     {
-      msyslog(LOG_ERR, "NeoClock4X(%d): control: unit invalid/inactive", unit);
+      msyslog(LOG_ERR, "REFCLOCK: NeoClock4X(%d): control: unit invalid/inactive", unit);
       return;
     }
 
   up = pp->unitptr;
   if(NULL == up)
     {
-      msyslog(LOG_ERR, "NeoClock4X(%d): control: unit invalid/inactive", unit);
+      msyslog(LOG_ERR, "REFCLOCK: NeoClock4X(%d): control: unit invalid/inactive", unit);
       return;
     }
 
@@ -634,7 +640,7 @@ neoclock4x_control(int unit,
 	{
 	  pp->fudgetime1 = in->fudgetime1;
 	  NLOG(NLOG_CLOCKINFO)
-	    msyslog(LOG_NOTICE, "NeoClock4X(%d): using fudgetime1 with %0.5fs from ntp.conf.",
+	    msyslog(LOG_NOTICE, "REFCLOCK: NeoClock4X(%d): using fudgetime1 with %0.5fs from ntp.conf.",
 		    unit, pp->fudgetime1);
 	}
 
@@ -642,12 +648,12 @@ neoclock4x_control(int unit,
       if(pp->sloppyclockflag & CLK_FLAG1)
 	{
 	  NLOG(NLOG_CLOCKINFO)
-	    msyslog(LOG_NOTICE, "NeoClock4X(%d): quartz clock is used to synchronize time if radio clock has no reception.", unit);
+	    msyslog(LOG_NOTICE, "REFCLOCK: NeoClock4X(%d): quartz clock is used to synchronize time if radio clock has no reception.", unit);
 	}
       else
 	{
 	  NLOG(NLOG_CLOCKINFO)
-	    msyslog(LOG_NOTICE, "NeoClock4X(%d): time is only adjusted with radio signal reception.", unit);
+	    msyslog(LOG_NOTICE, "REFCLOCK: NeoClock4X(%d): time is only adjusted with radio signal reception.", unit);
 	}
     }
 
@@ -666,12 +672,19 @@ neoclock4x_control(int unit,
       tt = add_var(&out->kv_list, sizeof(tmpbuf)-1, RO|DEF);
       snprintf(tt, sizeof(tmpbuf)-1, "calc_utc=\"%s\"", tmpbuf);
 
-      tt = add_var(&out->kv_list, 40, RO|DEF);
-      snprintf(tt, 39, "radiosignal=\"%s\"", up->radiosignal);
-      tt = add_var(&out->kv_list, 40, RO|DEF);
-      snprintf(tt, 39, "antenna1=\"%d\"", up->antenna1);
-      tt = add_var(&out->kv_list, 40, RO|DEF);
-      snprintf(tt, 39, "antenna2=\"%d\"", up->antenna2);
+#define MAXINTSIZE	20	/* max % of decimal digits in integer */
+#define S_RADIOSIGNAL	sizeof(up->radiosignal) + 15
+      tt = add_var(&out->kv_list, S_RADIOSIGNAL+1, RO|DEF);
+      snprintf(tt, S_RADIOSIGNAL, "radiosignal=\"%s\"", up->radiosignal);
+#undef S_RADIOSIGNAL 
+#define S_ANTENNA1	MAXINTSIZE + 12
+      tt = add_var(&out->kv_list, S_ANTENNA1+1, RO|DEF);
+      snprintf(tt, S_ANTENNA1, "antenna1=\"%d\"", up->antenna1);
+#undef S_ANTENNA1
+#define S_ANTENNA2	MAXINTSIZE + 12
+      tt = add_var(&out->kv_list, S_ANTENNA2+1, RO|DEF);
+      snprintf(tt, S_ANTENNA2, "antenna2=\"%d\"", up->antenna2);
+#undef S_ANTENNA2
       tt = add_var(&out->kv_list, 40, RO|DEF);
       if('A' == up->timesource)
 	snprintf(tt, 39, "timesource=\"radio\"");
@@ -693,14 +706,21 @@ neoclock4x_control(int unit,
         snprintf(tt, 39, "dststatus=\"winter\"");
       else
         snprintf(tt, 39, "dststatus=\"unknown\"");
-      tt = add_var(&out->kv_list, 80, RO|DEF);
-      snprintf(tt, 79, "firmware=\"%s\"", up->firmware);
-      tt = add_var(&out->kv_list, 40, RO|DEF);
-      snprintf(tt, 39, "firmwaretag=\"%c\"", up->firmwaretag);
+#define S_FIRMWARE	sizeof(up->firmware) + 13 
+      tt = add_var(&out->kv_list, S_FIRMWARE+1, RO|DEF);
+      snprintf(tt, S_FIRMWARE, "firmware=\"%s\"", up->firmware);
+#undef S_FIRMWARE
+#define S_FIRMWARETAG	sizeof(up->firmware) + 15 
+      tt = add_var(&out->kv_list, S_FIRMWARETAG+1, RO|DEF);
+      snprintf(tt, S_FIRMWARETAG, "firmwaretag=\"%c\"", up->firmwaretag);
+#undef S_FIRMWARETAG
       tt = add_var(&out->kv_list, 80, RO|DEF);
       snprintf(tt, 79, "driver version=\"%s\"", NEOCLOCK4X_DRIVER_VERSION);
-      tt = add_var(&out->kv_list, 80, RO|DEF);
-      snprintf(tt, 79, "serialnumber=\"%s\"", up->serial);
+#define S_SERIAL	sizeof(up->serial) + 16
+      tt = add_var(&out->kv_list, S_SERIAL+1, RO|DEF);
+      snprintf(tt, S_SERIAL, "serialnumber=\"%s\"", up->serial);
+#undef S_SERIAL
+#undef MAXINTSIZE
     }
 }
 
@@ -769,10 +789,10 @@ neol_mktime(int year,
   }
   return (((
             (unsigned long)(year/4 - year/100 + year/400 + 367*mon/12 + day) +
-            year*365 - 719499
-            )*24 + hour /* now have hours */
-           )*60 + min /* now have minutes */
-          )*60 + sec; /* finally seconds */
+            (unsigned int)year*365 - 719499
+            )*24 + (unsigned int)hour /* now have hours */
+           )*60 + (unsigned int)min /* now have minutes */
+          )*60 + (unsigned int)sec; /* finally seconds */
 }
 
 static void
@@ -784,11 +804,11 @@ neol_localtime(unsigned long utc,
 	       int* min,
 	       int* sec)
 {
-  *sec = utc % 60;
+  *sec = (int)(utc % 60);
   utc /= 60;
-  *min = utc % 60;
+  *min = (int)(utc % 60);
   utc /= 60;
-  *hour = utc % 24;
+  *hour = (int)(utc % 24);
   utc /= 24;
 
   /*             JDN Date 1/1/1970 */
@@ -858,13 +878,13 @@ neol_query_firmware(int fd,
 	{
 	  if(read_errors > 5)
 	    {
-	      msyslog(LOG_ERR, "NeoClock4X(%d): can't read firmware version (timeout)", unit);
+	      msyslog(LOG_ERR, "REFCLOCK: NeoClock4X(%d): can't read firmware version (timeout)", unit);
 	      strlcpy(tmpbuf, "unknown due to timeout", sizeof(tmpbuf));
 	      break;
 	    }
           if(chars_read > 500)
             {
-	      msyslog(LOG_ERR, "NeoClock4X(%d): can't read firmware version (garbage)", unit);
+	      msyslog(LOG_ERR, "REFCLOCK: NeoClock4X(%d): can't read firmware version (garbage)", unit);
 	      strlcpy(tmpbuf, "unknown due to garbage input", sizeof(tmpbuf));
 	      break;
             }
@@ -898,7 +918,7 @@ neol_query_firmware(int fd,
 	    }
 
 #if 0
-	  msyslog(LOG_NOTICE, "NeoClock4X(%d): firmware %c = %02Xh", unit, c, c);
+	  msyslog(LOG_NOTICE, "REFCLOCK: NeoClock4X(%d): firmware %c = %02Xh", unit, c, c);
 #endif
 
 	  if(0x0A == c || 0x0D == c)
@@ -935,7 +955,7 @@ neol_query_firmware(int fd,
     }
   else
     {
-      msyslog(LOG_ERR, "NeoClock4X(%d): can't query firmware version", unit);
+      msyslog(LOG_ERR, "REFCLOCK: NeoClock4X(%d): can't query firmware version", unit);
       strlcpy(tmpbuf, "unknown error", sizeof(tmpbuf));
     }
   if (strlcpy(firmware, tmpbuf, maxlen) >= maxlen)
@@ -944,11 +964,11 @@ neol_query_firmware(int fd,
   if(flag)
     {
       NLOG(NLOG_CLOCKINFO)
-	msyslog(LOG_INFO, "NeoClock4X(%d): firmware version: %s", unit, firmware);
+	msyslog(LOG_INFO, "REFCLOCK: NeoClock4X(%d): firmware version: %s", unit, firmware);
 
       if(strstr(firmware, "/R2"))
 	{
-	  msyslog(LOG_INFO, "NeoClock4X(%d): Your NeoClock4X uses the new R2 firmware release. Please note the changed LED behaviour.", unit);
+	  msyslog(LOG_INFO, "REFCLOCK: NeoClock4X(%d): Your NeoClock4X uses the new R2 firmware release. Please note the changed LED behaviour.", unit);
 	}
 
     }
@@ -976,7 +996,7 @@ neol_check_firmware(int unit,
 
   if('A' != *firmwaretag)
     {
-      msyslog(LOG_CRIT, "NeoClock4X(%d): firmware version \"%c\" not supported with this driver version!", unit, *firmwaretag);
+      msyslog(LOG_CRIT, "REFCLOCK: NeoClock4X(%d): firmware version \"%c\" not supported with this driver version!", unit, *firmwaretag);
       return false;
     }
 
