@@ -134,8 +134,7 @@ pps_start(
 	pp->stratum = STRATUM_UNSPEC;
 	memcpy((char *)&pp->refid, REFID, REFIDLEN);
 	peer->sstclktype = CTL_SST_TS_ATOM;
-	up = emalloc(sizeof(struct ppsunit));
-	memset(up, 0, sizeof(struct ppsunit));
+	up = emalloc_zero(sizeof(struct ppsunit));
 	pp->unitptr = up;
 
 	/*
@@ -143,11 +142,11 @@ pps_start(
 	 * not necessarily the port used for the associated radio.
 	 */
 	snprintf(device, sizeof(device), DEVICE, unit);
-	up->fddev = open(peer->ppspath ? peer->ppspath : device,
+	up->fddev = open(peer->cfg.ppspath ? peer->cfg.ppspath : device,
 			     O_RDWR, 0777);
 	if (up->fddev <= 0) {
 		msyslog(LOG_ERR,
-			"refclock_pps: %m");
+			"REFCLOCK: refclock_pps: %m");
 		return false;
 	}
 
@@ -214,7 +213,7 @@ pps_timer(
         }
         if (rc != PPS_OK) return;
 
-	peer->flags |= FLAG_PPS;
+	peer->cfg.flags |= FLAG_PPS;
 
 	/*
 	 * If flag4 is lit, record each second offset to clockstats.
@@ -256,13 +255,13 @@ pps_poll(
 	pp->polls++;
 
 	mprintf_clock_stats(peer,
-	    "%ld %d %d %d %d",
+	    "%lu %d %d %d %d",
 	    up->ppsctl.sequence,
 	    up->pcount, up->scount, up->kcount, up->rcount);
 	up->pcount = up->scount = up->kcount = up->rcount = 0;
 
 	if (pp->codeproc == pp->coderecv) {
-		peer->flags &= ~FLAG_PPS;
+		peer->cfg.flags &= ~FLAG_PPS;
 		refclock_report(peer, CEVNT_TIMEOUT);
 		return;
 	}
