@@ -17,6 +17,7 @@
 #include "ntp_refclock.h"
 #undef fileno
 #include "timespecops.h"
+#include "ntp_calendar.h"	/* for SECSPERHR */
 #undef fileno
 #include "ntp_stdlib.h"
 #include "ntp_assert.h"
@@ -134,12 +135,12 @@ getShmTime(
 	shmid=shmget(0x4e545030 + unit, sizeof (struct shmTime),
 		      IPC_CREAT | (forall ? 0666 : 0600));
 	if (shmid == -1) { /* error */
-		msyslog(LOG_ERR, "SHM shmget (unit %d): %m", unit);
+		msyslog(LOG_ERR, "REFCLOCK: SHM shmget (unit %d): %m", unit);
 		return NULL;
 	}
 	p = (struct shmTime *)shmat (shmid, 0, 0);
 	if (p == (struct shmTime *)-1) { /* error */
-		msyslog(LOG_ERR, "SHM shmat (unit %d): %m", unit);
+		msyslog(LOG_ERR, "REFCLOCK: SHM shmat (unit %d): %m", unit);
 		return NULL;
 	}
 
@@ -164,7 +165,7 @@ shm_start(
 	pp->io.datalen = 0;
 	pp->io.fd = -1;
 
-	up->forall = (unit >= 2) && !(peer->ttl & SHM_MODE_PRIVATE);
+	up->forall = (unit >= 2) && !(peer->cfg.ttl & SHM_MODE_PRIVATE);
 
 	up->shm = getShmTime(unit, up->forall);
 
@@ -183,7 +184,7 @@ shm_start(
 		pp->clockdesc = DESCRIPTION;
 		/* items to be changed later in 'shm_control()': */
 		up->max_delay = 5;
-		up->max_delta = 4*3600;
+		up->max_delta = 4 * SECSPERHR;
 		return true;
 	} else {
 		free(up);
@@ -218,8 +219,8 @@ shm_control(
 		return;
 	if (!(pp->sloppyclockflag & CLK_FLAG1))
 		up->max_delta = 0;
-	else if (pp->fudgetime2 < 1. || pp->fudgetime2 > 86400.)
-		up->max_delta = 4*3600;
+	else if (pp->fudgetime2 < 1. || pp->fudgetime2 > SECSPERDAY)
+		up->max_delta = 4 * SECSPERHR;
 	else
 		up->max_delta = (time_t)floor(pp->fudgetime2 + 0.5);
 }
@@ -351,7 +352,8 @@ static enum segstat_t shm_query(volatile struct shmTime *shm_in, struct shm_stat
      * (b) memset compiles to an uninterruptible single-instruction bitblt.
      */
     memory_barrier();
-    memcpy((void *)&shmcopy, (void *)shm, sizeof(struct shmTime));
+    /* structure copy, to preserve volatile */
+    shmcopy = *shm;
     shm->valid = 0;
     memory_barrier();
 
@@ -362,7 +364,7 @@ static enum segstat_t shm_query(volatile struct shmTime *shm_in, struct shm_stat
      */
     if (shmcopy.mode > 0 && cnt != shm->count) {
 	shm_stat->status = CLASH;
-	return shm_stat->status;
+	return (enum segstat_t)shm_stat->status;
     }
 
     shm_stat->status = OK;
@@ -390,8 +392,8 @@ static enum segstat_t shm_query(volatile struct shmTime *shm_in, struct shm_stat
 	*/
 	if (   ((cns_new - (unsigned)shm_stat->tvt.tv_nsec) < 1000)
 	       && ((rns_new - (unsigned)shm_stat->tvr.tv_nsec) < 1000)) {
-	    shm_stat->tvt.tv_nsec = cns_new;
-	    shm_stat->tvr.tv_nsec = rns_new;
+	    shm_stat->tvt.tv_nsec = (long)cns_new;
+	    shm_stat->tvr.tv_nsec = (long)rns_new;
 	}
 	/* At this point shm_stat->tvr and shm_stat->tvt contain valid ns-level
 	** timestamps, possibly generated by extending the old
@@ -413,8 +415,8 @@ static enum segstat_t shm_query(volatile struct shmTime *shm_in, struct shm_stat
 	*/
 	if (   ((cns_new - (unsigned)shm_stat->tvt.tv_nsec) < 1000)
 	       && ((rns_new - (unsigned)shm_stat->tvr.tv_nsec) < 1000)) {
-	    shm_stat->tvt.tv_nsec = cns_new;
-	    shm_stat->tvr.tv_nsec = rns_new;
+	    shm_stat->tvt.tv_nsec = (long)cns_new;
+	    shm_stat->tvr.tv_nsec = (long)rns_new;
 	}
 	/* At this point shm_stat->tvr and shm_stat->tvt contains valid ns-level
 	** timestamps, possibly generated by extending the old
@@ -436,7 +438,7 @@ static enum segstat_t shm_query(volatile struct shmTime *shm_in, struct shm_stat
     shm_stat->leap = shmcopy.leap;
     shm_stat->precision = shmcopy.precision;
 
-    return shm_stat->status;
+    return (enum segstat_t)shm_stat->status;
 }
 
 /*
@@ -469,7 +471,7 @@ shm_timer(
 		body has ipcrm'ed the old (unaccessible) shared mem segment */
 		shm = up->shm = getShmTime(unit, up->forall);
 		if (shm == NULL) {
-			DPRINTF(1, ("%s: no SHM segment\n",refclock_name(peer)));
+			DPRINT(1, ("%s: no SHM segment\n",refclock_name(peer)));
 			return;
 		}
 	}
@@ -479,33 +481,33 @@ shm_timer(
 
 	switch (status) {
 	case OK:
-	    DPRINTF(2, ("%s: SHM(%d) type %d sample\n",
-			refclock_name(peer), unit, shm_stat.mode));
+	    DPRINT(2, ("%s: SHM(%d) type %d sample\n",
+		       refclock_name(peer), unit, shm_stat.mode));
 	    break;
 	case NO_SEGMENT:
 	    /* should never happen, but is harmless */
 	    return;
 	case NOT_READY:
-	    DPRINTF(1, ("%s: SHM(%d) not ready\n",refclock_name(peer), unit));
+	    DPRINT(1, ("%s: SHM(%d) not ready\n",refclock_name(peer), unit));
 	    up->notready++;
 	    return;
 	case BAD_MODE:
-	    DPRINTF(1, ("%s: SHM(%d) type blooper, mode=%d\n",
-			refclock_name(peer), unit, shm->mode));
+	    DPRINT(1, ("%s: SHM(%d) type blooper, mode=%d\n",
+		       refclock_name(peer), unit, shm->mode));
 	    up->bad++;
 	    msyslog (LOG_ERR, "SHM(%d): bad mode found in shared memory: %d",
 		     unit, shm->mode);
 	    return;
 	case CLASH:
-	    DPRINTF(1, ("%s: type 1 access clash\n",
-			refclock_name(peer)));
+	    DPRINT(1, ("%s: type 1 access clash\n",
+		       refclock_name(peer)));
 	    msyslog (LOG_NOTICE, "SHM(%d): access clash in shared memory",
                         unit);
 	    up->clash++;
 	    return;
 	default:
-	    DPRINTF(1, ("%s: internal error, unknown SHM(%d) fetch status\n",
-			refclock_name(peer), unit));
+	    DPRINT(1, ("%s: internal error, unknown SHM(%d) fetch status\n",
+		       refclock_name(peer), unit));
 	    msyslog (LOG_NOTICE, "internal error, unknown SHM(%d) fetch status",
                         unit);
 	    up->bad++;
@@ -527,8 +529,8 @@ shm_timer(
 	/* check 1: age control of local time stamp */
 	tt = shm_stat.tvc.tv_sec - shm_stat.tvr.tv_sec;
 	if (tt < 0 || tt > up->max_delay) {
-		DPRINTF(1, ("%s:SHM(%d) stale/bad receive time, delay=%llds\n",
-			    refclock_name(peer), unit, (long long)tt));
+		DPRINT(1, ("%s:SHM(%d) stale/bad receive time, delay=%llds\n",
+			   refclock_name(peer), unit, (long long)tt));
 		up->bad++;
 		msyslog (LOG_ERR,
                          "SHM(%d): stale/bad receive time, delay=%llds",
@@ -541,8 +543,8 @@ shm_timer(
 	if (tt < 0)
 		tt = -tt;
 	if (up->max_delta > 0 && tt > up->max_delta) {
-		DPRINTF(1, ("%s: SHM(%d) diff limit exceeded, delta=%llds\n",
-			    refclock_name(peer), unit, (long long)tt));
+		DPRINT(1, ("%s: SHM(%d) diff limit exceeded, delta=%llds\n",
+			   refclock_name(peer), unit, (long long)tt));
 		up->bad++;
 		msyslog (LOG_ERR,
                          "SHM(%d): difference limit exceeded, delta=%llds\n",
@@ -551,7 +553,7 @@ shm_timer(
 	}
 
 	/* if we really made it to this point... we're winners! */
-	DPRINTF(2, ("%s: SHM(%d) feeding data\n", refclock_name(peer), unit));
+	DPRINT(2, ("%s: SHM(%d) feeding data\n", refclock_name(peer), unit));
 	tsrcv = tspec_stamp_to_lfp(shm_stat.tvr);
 	tsref = tspec_stamp_to_lfp(shm_stat.tvt);
 	pp->leap = (uint8_t)shm_stat.leap;
