@@ -116,7 +116,7 @@ zyfer_start(
 	struct peer *peer
 	)
 {
-	register struct zyferunit *up;
+	struct zyferunit *up;
 	struct refclockproc *pp;
 	int fd;
 	char device[20];
@@ -126,20 +126,19 @@ zyfer_start(
 	 * Something like LDISC_ACTS that looked for ! would be nice...
 	 */
 	snprintf(device, sizeof(device), DEVICE, unit);
-	fd = refclock_open(peer->path ? peer->path : device,
-			   peer->baud ? peer->baud : SPEED232,
+	fd = refclock_open(peer->cfg.path ? peer->cfg.path : device,
+			   peer->cfg.baud ? peer->cfg.baud : SPEED232,
 			   LDISC_RAW);
 	if (fd <= 0)
 		/* coverity[leaked_handle] */
 		return false;
 
-	msyslog(LOG_NOTICE, "zyfer(%d) fd: %d", unit, fd);
+	msyslog(LOG_NOTICE, "REFCLOCK: zyfer(%d) fd: %d", unit, fd);
 
 	/*
 	 * Allocate and initialize unit structure
 	 */
-	up = emalloc(sizeof(struct zyferunit));
-	memset(up, 0, sizeof(struct zyferunit));
+	up = emalloc_zero(sizeof(struct zyferunit));
 	pp = peer->procptr;
 	pp->io.clock_recv = zyfer_receive;
 	pp->io.srcclock = peer;
@@ -177,7 +176,7 @@ zyfer_shutdown(
 	struct peer *peer
 	)
 {
-	register struct zyferunit *up;
+	struct zyferunit *up;
 	struct refclockproc *pp;
 
 	UNUSED_ARG(unit);
@@ -199,7 +198,7 @@ zyfer_receive(
 	struct recvbuf *rbufp
 	)
 {
-	register struct zyferunit *up;
+	struct zyferunit *up;
 	struct refclockproc *pp;
 	struct peer *peer;
 	int tmode;		/* Time mode */
@@ -305,7 +304,7 @@ zyfer_poll(
 	struct peer *peer
 	)
 {
-	register struct zyferunit *up;
+	struct zyferunit *up;
 	struct refclockproc *pp;
 
 	UNUSED_ARG(unit);
