@@ -32,7 +32,18 @@
 # define TVUTOTSF(tvu)	\
 	(uint32_t)((((uint64_t)(tvu) << 32) + US_PER_S / 2) / US_PER_S)
 
-#define NS_PER_MS_FLOAT	1000.0
+/* nano seconds per micro second */
+#define NS_PER_US_FLOAT	1000.0
+
+#ifndef HAVE_STRUCT_NTPTIMEVAL
+struct ntptimeval
+{
+	struct timeval	time;		/* current time (ro) */
+	long int	maxerror;	/* maximum error (us) (ro) */
+	long int	esterror;	/* estimated error (us) (ro) */
+};
+
+#endif	/* !HAVE_STRUCT_NTPTIMEVAL */
 
 /* MUSL port shim */
 #ifndef HAVE_NTP_GETTIME
@@ -74,11 +85,11 @@ int ntp_gettime(struct ntptimeval *ntv)
 /*
  * Function prototypes
  */
-const char *	snprintb	(size_t, char *, u_int, const char *);
+const char *	snprintb	(size_t, char *, unsigned int, const char *);
 const char *	timex_state	(int);
 
 #ifdef SIGSYS
-void pll_trap		(int);
+void pll_trap(int) __attribute__((noreturn));
 
 static struct sigaction newsigsys;	/* new sigaction status */
 static struct sigaction sigsys;		/* current sigaction status */
@@ -97,8 +108,6 @@ main(
 	char *argv[]
 	)
 {
-	extern int ntp_optind;
-	extern char *ntp_optarg;
 	struct ntptimeval ntv;
 	struct timeval tv;
 	struct timex ntx, _ntx;
@@ -131,13 +140,11 @@ main(
 			ntx.modes |= MOD_NANO;
 			break;
 #endif
-#ifdef NTP_API
-# if NTP_API > 3
+#if defined NTP_API && NTP_API > 3
 		case 'T':
 			ntx.modes = MOD_TAI;
 			ntx.constant = atoi(ntp_optarg);
 			break;
-# endif
 #endif
 		case 'c':
 			cost++;
@@ -212,12 +219,8 @@ main(
 #else
 "",
 #endif
-#ifdef NTP_API
-# if NTP_API > 3
+#if defined NTP_API && NTP_API > 3
 "-T tai_offset	set TAI offset\n",
-# else
-"",
-# endif
 #else
 "",
 #endif
@@ -297,7 +300,7 @@ main(
 		const char *ofmt2 = "  time %s, (.%0*d),\n";
 		const char *ofmt3 = "  maximum error %lu us, estimated error %lu us";
 		const char *ofmt4 = "  ntptime=%x.%x unixtime=%x.%0*d %s";
-#if NTP_API > 3
+#if defined NTP_API && NTP_API > 3
 		const char *ofmt5 = ", TAI offset %ld\n";
 #else
 		const char *ofmt6 = "\n";
@@ -307,7 +310,7 @@ main(
 		const char *jfmt2 = "\"time\":\"%s\",\"fractional-time\":\".%0*d\",";
 		const char *jfmt3 = "\"maximum-error\":%lu,\"estimated-error\":%lu,";
 		const char *jfmt4 = "\"raw-ntp-time\":\"%x.%x\",\"raw-unix-time\":\"%x.%0*d %s\",";
-#if NTP_API > 3
+#if defined NTP_API && NTP_API > 3
 		const char *jfmt5 = "\"TAI-offset\":%d,";
 #else
 		const char *jfmt6 = "";
@@ -328,10 +331,11 @@ main(
 		setlfpfrac(ts, lfpfrac(ts) + ts_roundbit);
 		setlfpfrac(ts, lfpfrac(ts) & ts_mask);
 		printf(json ? jfmt2 : ofmt2,  json ? rfc3339date(ts) : prettydate(ts), fdigits, (int)time_frac);
-		printf(json ? jfmt3 : ofmt3,  (u_long)ntv.maxerror, (u_long)ntv.esterror);
+		printf(json ? jfmt3 : ofmt3,  (unsigned long)ntv.maxerror, (unsigned long)ntv.esterror);
 		if (rawtime)
 			printf(json ? jfmt4 : ofmt4,
-			       (u_int)lfpuint(ts), (u_int)lfpfrac(ts),
+			       (unsigned int)lfpuint(ts),
+			       (unsigned int)lfpfrac(ts),
 			       (int)ntv.time.tv_sec, fdigits,
 			       (int)time_frac,
 
@@ -350,39 +354,39 @@ main(
 	} else {
 		char binbuf[132];
 		/* oldstyle formats */
-		char *ofmt7 = "ntp_adjtime() returns code %d (%s)\n";
-		char *ofmt8 = "  modes %s,\n";
-		char *ofmt9 = "  offset %.3f";
-		char *ofmt10 = " us, frequency %.3f ppm, interval %d s,\n";
-		char *ofmt11 = "  maximum error %lu us, estimated error %lu us,\n";
-		char *ofmt12 = "  status %s,\n";
-		char *ofmt13 = "  time constant %lu, precision %.3f us, tolerance %.0f ppm,\n";
-		char *ofmt14 = "  pps frequency %.3f ppm, stability %.3f ppm, jitter %.3f us,\n";
-		char *ofmt15 = "  intervals %lu, jitter exceeded %lu, stability exceeded %lu, errors %lu.\n";
+		const char *ofmt7 = "ntp_adjtime() returns code %d (%s)\n";
+		const char *ofmt8 = "  modes %s,\n";
+		const char *ofmt9 = "  offset %.3f";
+		const char *ofmt10 = " us, frequency %.3f ppm, interval %d s,\n";
+		const char *ofmt11 = "  maximum error %lu us, estimated error %lu us,\n";
+		const char *ofmt12 = "  status %s,\n";
+		const char *ofmt13 = "  time constant %lu, precision %.3f us, tolerance %.0f ppm,\n";
+		const char *ofmt14 = "  pps frequency %.3f ppm, stability %.3f ppm, jitter %.3f us,\n";
+		const char *ofmt15 = "  intervals %lu, jitter exceeded %lu, stability exceeded %lu, errors %lu.\n";
 		/* JSON formats */
-		char *jfmt7 = "\"adjtime-code\":%d,\"adjtime-status\":\"%s\",";
-		char *jfmt8 = "\"modes\":\"%s\",";
-		char *jfmt9 = "\"offset\":%.3f,";
-		char *jfmt10 = "\"frequency\":%.3f,\"interval\":%d,";
-		char *jfmt11 = "\"maximum-error\":%lu,\"estimated-error\":%lu,";
-		char *jfmt12 = "\"status\":\"%s\",";
-		char *jfmt13 = "\"time-constant\":%lu,\"precision\":%.3f,\"tolerance\":%.0f,";
-		char *jfmt14 = "\"pps-frequency\":%.3f,\"stability\":%.3f,\"jitter\":%.3f,";
-		char *jfmt15 = "\"intervals\":%lu,\"jitter-exceeded\":%lu,\"stability-exceeded\":%lu,\"errors:%lu\n";
+		const char *jfmt7 = "\"adjtime-code\":%d,\"adjtime-status\":\"%s\",";
+		const char *jfmt8 = "\"modes\":\"%s\",";
+		const char *jfmt9 = "\"offset\":%.3f,";
+		const char *jfmt10 = "\"frequency\":%.3f,\"interval\":%d,";
+		const char *jfmt11 = "\"maximum-error\":%lu,\"estimated-error\":%lu,";
+		const char *jfmt12 = "\"status\":\"%s\",";
+		const char *jfmt13 = "\"time-constant\":%lu,\"precision\":%.3f,\"tolerance\":%.0f,";
+		const char *jfmt14 = "\"pps-frequency\":%.3f,\"stability\":%.3f,\"jitter\":%.3f,";
+		const char *jfmt15 = "\"intervals\":%lu,\"jitter-exceeded\":%lu,\"stability-exceeded\":%lu,\"errors:%lu\n";
 
 		flash = ntx.status;
 		printf(json ? jfmt7 : ofmt7, status, timex_state(status));
 		printf(json ? jfmt8 : ofmt8,
 		       snprintb(sizeof(binbuf), binbuf, ntx.modes, TIMEX_MOD_BITS));
-		ftemp = (double)ntx.offset/NS_PER_MS_FLOAT;
+		ftemp = (double)ntx.offset/NS_PER_US_FLOAT;
 		printf(json ? jfmt9 : ofmt9, ftemp);
 		ftemp = FP_UNSCALE(ntx.freq);
 		printf(json ? jfmt10 : ofmt10, ftemp, 1 << ntx.shift);
 		printf(json ? jfmt11 : ofmt11,
-		     (u_long)ntx.maxerror, (u_long)ntx.esterror);
+		     (unsigned long)ntx.maxerror, (unsigned long)ntx.esterror);
 		printf(json ? jfmt12 : ofmt12,
 		       snprintb(sizeof(binbuf), binbuf,
-			       (u_int)ntx.status, TIMEX_STA_BITS));
+			       (unsigned int)ntx.status, TIMEX_STA_BITS));
 		ftemp = FP_UNSCALE(ntx.tolerance);
 		/*
 		 * Before the introduction of ntp_adjtime_ns() the
@@ -393,16 +397,16 @@ main(
 		 */
 		gtemp = (double)ntx.precision;
 		printf(json ? jfmt13 : ofmt13,
-			(u_long)ntx.constant, gtemp, ftemp);
+			(unsigned long)ntx.constant, gtemp, ftemp);
 		if (ntx.shift != 0) {
 		  ftemp = FP_UNSCALE(ntx.ppsfreq);
 		  gtemp = FP_UNSCALE(ntx.stabil);
-			htemp = (double)ntx.jitter/NS_PER_MS_FLOAT;
+			htemp = (double)ntx.jitter/NS_PER_US_FLOAT;
 			printf(json ? jfmt14 : ofmt14,
 			    ftemp, gtemp, htemp);
 			printf(json ? jfmt15 : ofmt15,
-			    (u_long)ntx.calcnt, (u_long)ntx.jitcnt,
-			    (u_long)ntx.stbcnt, (u_long)ntx.errcnt);
+			    (unsigned long)ntx.calcnt, (unsigned long)ntx.jitcnt,
+			    (unsigned long)ntx.stbcnt, (unsigned long)ntx.errcnt);
 		}
 		if (json)
 		    /* hack to avoid trailing comma - not semabtically needed */ 
@@ -447,7 +451,7 @@ const char *
 snprintb(
 	size_t		buflen,
 	char *		buf,
-	u_int		v,
+	unsigned int	v,
 	const char *	bits
 	)
 {
@@ -469,7 +473,7 @@ snprintb(
 		*cp++ = '(';
 		any = false;
 		while ((i = *bits++) != 0) {
-			if (v & (1 << (i - 1))) {
+			if (v & (unsigned int)(1 << (i - 1))) {
 				if (any) {
 					*cp++ = ',';
 					if (cp >= cplim)
