@@ -1,3 +1,5 @@
+# -*- coding: utf-8 -*-
+
 """
 statfiles.py - class for digesting and plotting NTP logfiles
 
@@ -57,6 +59,53 @@ class NTPStats:
         "get Unix time from converted line."
         return float(line.split()[0])
 
+    @staticmethod
+    def percentiles(percents, values):
+        "Return given percentiles of a given row in a given set of entries."
+        "assuming values are already split and sorted"
+        ret = {}
+        length = len(values)
+        if 1 >= length:
+            # uh, oh...
+            if 1 == length:
+                # just one data value, set all to that one value
+                v = values[0]
+            else:
+                # no data, set all to zero
+                v = 0
+            for perc in percents:
+                ret["p" + str(perc)] = v
+        else:
+            for perc in percents:
+                if perc == 100:
+                    ret["p100"] = values[length - 1]
+                else:
+                    ret["p" + str(perc)] = values[int(length * (perc/100))]
+        return ret
+
+    @staticmethod
+    def ip_label(key):
+        "Produce appropriate label for an IP address."
+        # If it's a new-style NTPsep clock label, pass it through,
+        # Otherwise we expect it to be an IP address and the next guard fires
+        if key[0].isdigit():
+            # TO BE REMOVED SOMEDAY
+            # Clock address - only possible if we're looking at a logfile made
+            # by NTP Classic or an NTPsec version configured with
+            # --enable-classic-mode.  Nasty that we have to emit a numeric
+            # driver type here.
+            if key.startswith("127.127."):
+                (_, _, t, u) = key.split(".")
+                return "REFCLOCK(type=%s,unit=%s)" % (t, u)
+            # Ordinary IP address - replace with primary hostname.
+            # Punt if the lookup fails.
+            try:
+                (hostname, _, _) = socket.gethostbyaddr(key)
+                return hostname
+            except socket.herror:
+                pass
+        return key      # Someday, be smarter than this.
+
     def __init__(self, statsdir, sitename=None,
                  period=None, starttime=None, endtime=None):
         "Grab content of logfiles, sorted by timestamp."
@@ -85,79 +134,72 @@ class NTPStats:
                              % statsdir)
             raise SystemExit(1)
 
-        for stem in ("clockstats", "peerstats", "loopstats", "rawstats",
-                     "temps", "gpsd"):
-            lines = []
-            try:
-                pattern = os.path.join(statsdir, stem)
-                if stem != "temps" and stem != "gpsd":
-                    pattern += "."
-                for logpart in glob.glob(pattern + "*"):
-                    # skip files older than starttime
-                    if starttime > os.path.getmtime(logpart):
-                        continue
-                    if logpart.endswith("gz"):
-                        lines += gzip.open(logpart, 'rt').readlines()
-                    else:
-                        lines += open(logpart, 'r').readlines()
-            except IOError:
-                sys.stderr.write("ntpviz: WARNING: could not read %s\n"
-                                 % logpart)
-                pass
+        self.clockstats = []
+        self.peerstats = []
+        self.loopstats = []
+        self.rawstats = []
+        self.temps = []
+        self.gpsd = []
 
-            lines1 = []
-            if stem == "temps" or stem == "gpsd":
-                # temps and gpsd are already in UNIX time
-                for line in lines:
-                    split = line.split()
-                    if 3 > len(split):
-                        # skip short lines
-                        continue
+        for stem in ("clockstats", "peerstats", "loopstats",
+                     "rawstats", "temps", "gpsd"):
+            lines = self.__load_stem(statsdir, stem)
+            processed = self.__process_stem(stem, lines)
+            setattr(self, stem, processed)
 
-                    try:
-                        t = float(split[0])
-                    except:
-                        # ignore comment lines, lines with no time
-                        continue
-
-                    if starttime <= t <= endtime:
-                        # prefix with int milli sec.
-                        split.insert(0, int(t * 1000))
-                        lines1.append(split)
-            else:
-                # Morph first fields into Unix time with fractional seconds
-                # ut into nice dictionary of dictionary rows
-                lines1 = NTPStats.unixize(lines, starttime, endtime)
-
-            # Sort by datestamp
-            # by default, a tuple sort()s on the 1st item, which is a nice
-            # integer of milli seconds.  This is faster than using
-            # cmp= or key=
-            lines1.sort()
-            setattr(self, stem, lines1)
-
-    def percentiles(self, percents, values):
-        "Return given percentiles of a given row in a given set of entries."
-        "assuming values are already split and sorted"
-        ret = {}
-        length = len(values)
-        if 1 >= length:
-            # uh, oh...
-            if 1 == length:
-                # just one data value, set all to that one value
-                v = values[0]
-            else:
-                # no data, set all to zero
-                v = 0
-            for perc in percents:
-                ret["p" + str(perc)] = v
-        else:
-            for perc in percents:
-                if perc == 100:
-                    ret["p100"] = values[length - 1]
+    def __load_stem(self, statsdir, stem):
+        lines = []
+        try:
+            pattern = os.path.join(statsdir, stem)
+            if stem != "temps" and stem != "gpsd":
+                pattern += "."
+            for logpart in glob.glob(pattern + "*"):
+                # skip files older than starttime
+                if self.starttime > os.path.getmtime(logpart):
+                    continue
+                if logpart.endswith("gz"):
+                    lines += gzip.open(logpart, 'rt').readlines()
                 else:
-                    ret["p" + str(perc)] = values[int(length * (perc/100))]
-        return ret
+                    lines += open(logpart, 'r').readlines()
+        except IOError:
+            sys.stderr.write("ntpviz: WARNING: could not read %s\n"
+                             % logpart)
+            pass
+
+        return lines
+
+    def __process_stem(self, stem, lines):
+        lines1 = []
+        if stem == "temps" or stem == "gpsd":
+            # temps and gpsd are already in UNIX time
+            for line in lines:
+                split = line.split()
+                if 3 > len(split):
+                    # skip short lines
+                    continue
+
+                try:
+                    t = float(split[0])
+                except:
+                    # ignore comment lines, lines with no time
+                    continue
+
+                if self.starttime <= t <= self.endtime:
+                    # prefix with int milli sec.
+                    split.insert(0, int(t * 1000))
+                    lines1.append(split)
+        else:
+            # Morph first fields into Unix time with fractional seconds
+            # ut into nice dictionary of dictionary rows
+            lines1 = NTPStats.unixize(lines, self.starttime, self.endtime)
+            
+        # Sort by datestamp
+        # by default, a tuple sort()s on the 1st item, which is a nice
+        # integer of milli seconds.  This is faster than using
+        # cmp= or key=
+        lines1.sort()
+        return lines1
+
 
     def peersplit(self):
         "Return a dictionary mapping peerstats IPs to entry subsets."
@@ -204,28 +246,6 @@ class NTPStats:
                 pass
         return tempsmap
 
-    def ip_label(self, key):
-        "Produce appropriate label for an IP address."
-        # If it's a new-style NTPsep clock label, pass it through,
-        # Otherwise we expect it to be an IP address and the next guard fires
-        if key[0].isdigit():
-            # TO BE REMOVED SOMEDAY
-            # Clock address - only possible if we're looking at a logfile made
-            # by NTP Classic or an NTPsec version configured with
-            # --enable-classic-mode.  Nasty that we have to emit a numeric
-            # driver type here.
-            if key.startswith("127.127."):
-                (_, _, t, u) = key.split(".")
-                return "REFCLOCK(type=%s,unit=%s)" % (t, u)
-            # Ordinary IP address - replace with primary hostname.
-            # Punt if the lookup fails.
-            try:
-                (hostname, _, _) = socket.gethostbyaddr(key)
-                return hostname
-            except socket.herror:
-                pass
-        return key      # Someday, be smarter than this.
-
 
 def iso_to_posix(s):
     "Accept timestamps in ISO 8661 format or numeric POSIX time. UTC only."
