@@ -49,7 +49,7 @@ static void RunAllTests(void)
 	RUN_TEST_GROUP(lfptostr);
 	RUN_TEST_GROUP(macencrypt);
 	RUN_TEST_GROUP(msyslog);
-	RUN_TEST_GROUP(netof);
+	RUN_TEST_GROUP(netof6);
 	RUN_TEST_GROUP(numtoa);
 	RUN_TEST_GROUP(prettydate);
 	RUN_TEST_GROUP(recvbuff);
@@ -62,6 +62,12 @@ static void RunAllTests(void)
 	RUN_TEST_GROUP(ymd2yd);
 #endif
 
+#ifdef TEST_LIBPARSE
+	RUN_TEST_GROUP(binio);
+	RUN_TEST_GROUP(gpstolfp);
+	RUN_TEST_GROUP(ieee754io);
+#endif
+
 #ifdef TEST_NTPD
 	RUN_TEST_GROUP(leapsec);
 	RUN_TEST_GROUP(hackrestrict);
@@ -72,7 +78,6 @@ static void RunAllTests(void)
 
 int main(int argc, const char * argv[]) {
 
-	init_lib();
 	init_auth();
 	init_network();
 
