@@ -29,18 +29,40 @@ TEST_TEAR_DOWN(clocktime) {
 // test cases
 
 TEST(clocktime, CurrentYear) {
-	// Timestamp: 2010-06-24 12:50:00Z
+	// Timestamp: 2010-06-24 12:50:00Z, no year passed in
 	const uint32_t timestamp = 3486372600UL;
 	const uint32_t expected	= timestamp; // exactly the same.
 
-	const int yday=175, hour=12, minute=50, second=0, tzoff=0;
+	const int year=0, yday=175, hour=12, minute=50, second=0, tzoff=0;
 
 	uint32_t yearstart=0;
 	uint32_t actual;
 
-	TEST_ASSERT_TRUE(clocktime(yday, hour, minute, second, tzoff, timestamp,
-						  &yearstart, &actual));
+	TEST_ASSERT_TRUE(clocktime(year, yday, hour, minute, second,
+				   tzoff, timestamp, &yearstart, &actual));
 	TEST_ASSERT_EQUAL(expected, actual);
+	TEST_ASSERT_EQUAL(yearstart, 3471292800);
+}
+
+TEST(clocktime, CurrentYearExplicit) {
+	// Timestamp: 2010-06-24 12:50:00Z, explicit year passed in
+	const uint32_t timestamp = 3486372600UL;
+	const uint32_t expected	= timestamp; // exactly the same.
+
+	const int year=2010, yday=175, hour=12, minute=50, second=0, tzoff=0;
+
+	uint32_t yearstart=0;
+	uint32_t actual;
+
+	TEST_ASSERT_TRUE(clocktime(year, yday, hour, minute, second,
+				   tzoff, timestamp, &yearstart, &actual));
+	/* If this assertion fails with "Expected 3486372600 was
+	 * 104913720" that's a 32-bit integer overflow and your compiler
+	 * is failing to cast to int properly inside clocktime. 
+	 * Observed on Mac OS X.
+	 */
+	TEST_ASSERT_EQUAL(expected, actual);
+	TEST_ASSERT_EQUAL(yearstart, 3471292800);
 }
 
 TEST(clocktime, CurrentYearFuzz) {
@@ -55,13 +77,13 @@ TEST(clocktime, CurrentYearFuzz) {
 	const uint32_t timestamp = 3486372600UL; // 2010-06-24 12:50:00Z
 	const uint32_t expected	= 3486369600UL; // 2010-06-24 12:00:00Z
 
-	const int yday=175, hour=12, minute=0, second=0, tzoff=0;
+	const int year=0, yday=175, hour=12, minute=0, second=0, tzoff=0;
 
 	uint32_t yearstart=0;
 	uint32_t actual;
 
-	TEST_ASSERT_TRUE(clocktime(yday, hour, minute, second, tzoff, timestamp,
-						  &yearstart, &actual));
+	TEST_ASSERT_TRUE(clocktime(year, yday, hour, minute, second,
+				   tzoff, timestamp, &yearstart, &actual));
 	TEST_ASSERT_EQUAL(expected, actual);
 }
 
@@ -75,13 +97,13 @@ TEST(clocktime, TimeZoneOffset) {
 	const uint32_t timestamp = 3486369600UL;
 	const uint32_t expected	= timestamp;
 
-	const int yday=175, hour=4, minute=0, second=0, tzoff=8;
+	const int year=0, yday=175, hour=4, minute=0, second=0, tzoff=8;
 
 	uint32_t yearstart=0;
 	uint32_t actual;
 
-	TEST_ASSERT_TRUE(clocktime(yday, hour, minute, second, tzoff, timestamp,
-						  &yearstart, &actual));
+	TEST_ASSERT_TRUE(clocktime(year, yday, hour, minute, second,
+				   tzoff, timestamp, &yearstart, &actual));
 	TEST_ASSERT_EQUAL(expected, actual);
 }
 
@@ -94,13 +116,13 @@ TEST(clocktime, WrongYearStart) {
 	const uint32_t timestamp = 3471418800UL;
 	const uint32_t expected	= timestamp;
 
-	const int yday=2, hour=11, minute=0, second=0, tzoff=0;
+	const int year=0, yday=2, hour=11, minute=0, second=0, tzoff=0;
 
 	uint32_t yearstart = 302024100UL; // Yearstart of 2009.
 	uint32_t actual;
 
-	TEST_ASSERT_TRUE(clocktime(yday, hour, minute, second, tzoff, timestamp,
-						  &yearstart, &actual));
+	TEST_ASSERT_TRUE(clocktime(year, yday, hour, minute, second,
+				   tzoff, timestamp, &yearstart, &actual));
 	TEST_ASSERT_EQUAL(expected, actual);
 }
 
@@ -113,13 +135,13 @@ TEST(clocktime, PreviousYear) {
 	const uint32_t timestamp = 3471296400UL;
 	const uint32_t expected	= 3471289200UL;
 
-	const int yday=365, hour=23, minute=0, second=0, tzoff=0;
+	const int year=0, yday=365, hour=23, minute=0, second=0, tzoff=0;
 
 	uint32_t yearstart = 0;
 	uint32_t actual;
 
-	TEST_ASSERT_TRUE(clocktime(yday, hour, minute, second, tzoff, timestamp,
-						  &yearstart, &actual));
+	TEST_ASSERT_TRUE(clocktime(year, yday, hour, minute, second,
+				   tzoff, timestamp, &yearstart, &actual));
 	TEST_ASSERT_EQUAL(expected, actual);
 }
 
@@ -132,12 +154,12 @@ TEST(clocktime, NextYear) {
 	const uint32_t timestamp = 3471289200UL;
 	const uint32_t expected	= 3471296400UL;
 
-	const int yday=1, hour=1, minute=0, second=0, tzoff=0;
+	const int year=0, yday=1, hour=1, minute=0, second=0, tzoff=0;
 	uint32_t yearstart = 0;
 	uint32_t actual;
 
-	TEST_ASSERT_TRUE(clocktime(yday, hour, minute, second, tzoff, timestamp,
-						  &yearstart, &actual));
+	TEST_ASSERT_TRUE(clocktime(year, yday, hour, minute, second,
+				   tzoff, timestamp, &yearstart, &actual));
 	TEST_ASSERT_EQUAL(expected, actual);
 }
 
@@ -145,24 +167,24 @@ TEST(clocktime, NoReasonableConversion) {
 	/* Timestamp is: 2010-01-02 11:00:00Z */
 	const uint32_t timestamp = 3471418800UL;
 
-	const int yday=100, hour=12, minute=0, second=0, tzoff=0;
+	const int year=0, yday=100, hour=12, minute=0, second=0, tzoff=0;
 	uint32_t yearstart = 0;
 	uint32_t actual;
 
-	TEST_ASSERT_FALSE(clocktime(yday, hour, minute, second, tzoff, timestamp,
-						   &yearstart, &actual));
+	TEST_ASSERT_FALSE(clocktime(year, yday, hour, minute, second,
+				    tzoff, timestamp, &yearstart, &actual));
 }
 
 TEST(clocktime, AlwaysInLimit) {
 	/* Timestamp is: 2010-01-02 11:00:00Z */
 	const uint32_t timestamp = 3471418800UL;
-	const u_short prime_incs[] = { 127, 151, 163, 179 };
-	int	cyc;
-	int	yday;
-	u_char	whichprime;
-	u_short	ydayinc;
-	int	hour;
-	int	minute;
+	const unsigned short prime_incs[] = { 127, 151, 163, 179 };
+	int		cyc;
+	int		yday;
+	unsigned char	whichprime;
+	unsigned short	ydayinc;
+	int		hour;
+	int		minute;
 	uint32_t	yearstart;
 	uint32_t	actual;
 	uint32_t	diff;
@@ -171,11 +193,11 @@ TEST(clocktime, AlwaysInLimit) {
 	for (cyc = 0; cyc < 5; cyc++) {
 		settime(1900 + cyc * 65, 1, 1, 0, 0, 0);
 		for (yday = -26000; yday < 26000; yday += ydayinc) {
-			whichprime = abs(yday) % COUNTOF(prime_incs);
+			whichprime = abs(yday) % (int)COUNTOF(prime_incs);
 			ydayinc = prime_incs[whichprime];
 			for (hour = -204; hour < 204; hour += 2) {
 				for (minute = -60; minute < 60; minute++) {
-					clocktime(yday, hour, minute, 30, 0,
+				    (void)clocktime(0, yday, hour, minute, 30, 0,
 						  timestamp, &yearstart, &actual);
 					diff = actual - timestamp;
 					if (diff >= 0x80000000UL) {
@@ -190,6 +212,7 @@ TEST(clocktime, AlwaysInLimit) {
 
 TEST_GROUP_RUNNER(clocktime) {
 	RUN_TEST_CASE(clocktime, CurrentYear);
+	RUN_TEST_CASE(clocktime, CurrentYearExplicit);
 	RUN_TEST_CASE(clocktime, CurrentYearFuzz);
 	RUN_TEST_CASE(clocktime, TimeZoneOffset);
 	RUN_TEST_CASE(clocktime, WrongYearStart);
