@@ -3,6 +3,7 @@
 #include "ntp_types.h"
 #include "ntp_fp.h"
 #include "timespecops.h"
+#include "ntp_calendar.h"
 
 #include "unity.h"
 #include "unity_fixture.h"
@@ -34,7 +35,7 @@ struct lfpfracdata {
 
 TEST_GROUP(timespecops);
 
-TEST_SETUP(timespecops) {init_lib();}
+TEST_SETUP(timespecops) {}
 
 TEST_TEAR_DOWN(timespecops) {}
 
@@ -59,11 +60,12 @@ static struct timespec timespec_init(time_t hi, long lo)
 
 static bool AssertFpClose(const l_fp m, const l_fp n, const l_fp limit)
 {
-	int64_t diff = m - n;
+	int64_t diff = (int64_t)(m - n);
 	if ((l_fp)llabs(diff) <= limit)
 		return true;
 	else {
-		printf("m_expr which is %s \nand\nn_expr which is %s\nare not close; diff=%susec\n", lfptoa(m, 10), lfptoa(n, 10), lfptoa(diff, 10));
+		printf("m_expr which is %s \nand\nn_expr which is %s\nare not close; diff=%susec\n",
+                       lfptoa(m, 10), lfptoa(n, 10), lfptoa((l_fp)diff, 10));
 		return false;
 	}
 }
@@ -490,7 +492,7 @@ TEST(timespecops, test_ToLFPbittest) {
 	uint32_t i;
 
 	for (i = 0; i < 1000000000; i+=1000) {
-		struct timespec a = timespec_init(1, i);
+		struct timespec a = timespec_init(1, (long)i);
 		l_fp E= lfpinit(1, my_tick_to_tsf(i));
 		l_fp r;
 
@@ -539,7 +541,7 @@ TEST(timespecops, test_ToLFPabs) {
 
 	for (i = 0; i < (int)COUNTOF(fdata); ++i) {
 		struct timespec a = timespec_init(1, fdata[i].nsec);
-		l_fp E = lfpinit(1 + JAN_1970, fdata[i].frac);
+		l_fp E = lfpinit((int)(1 + JAN_1970), fdata[i].frac);
 		l_fp r;
 
 		r = tspec_stamp_to_lfp(a);
@@ -561,7 +563,7 @@ TEST(timespecops, test_FromLFPbittest) {
 	// every 1000 fractional units.
 	uint32_t tsf;
 	for (tsf = 0; tsf < ~((uint32_t)(1000)); tsf += 1000) {
-		struct timespec E = timespec_init(1, my_tsf_to_tick(tsf));
+		struct timespec E = timespec_init(1, (long)my_tsf_to_tick(tsf));
 		l_fp a = lfpinit(1, tsf);
 		struct timespec r;
 
@@ -616,7 +618,7 @@ TEST(timespecops, test_LFProundtrip) {
 
 	for (t = -1; t < 2; ++t)
 		for (i = 4999; i < 1000000000; i += 10007) {
-			struct timespec E = timespec_init(t, i);
+			struct timespec E = timespec_init(t, (long)i);
 			l_fp a;
 			struct timespec r;
 
