@@ -83,7 +83,7 @@ static const char leap2 [] =
     "2950473600	28	# 1 Jul 1993\n"
     "#\n";
 
-// Faked table with a leap second removal at 2009 
+// Faked table with a leap second removal at 2009
 static const char leap3 [] =
     "#\n"
     "#@ 	3610569600\n"
@@ -274,9 +274,9 @@ setup_clear_table(void)
 /*
 std::string CalendarToString(const calendar &cal) {
 	std::ostringstream ss;
-	ss << cal.year << "-" << (u_int)cal.month << "-" << (u_int)cal.monthday
-	   << " (" << cal.yearday << ") " << (u_int)cal.hour << ":"
-	   << (u_int)cal.minute << ":" << (u_int)cal.second;
+	ss << cal.year << "-" << (unsigned int)cal.month << "-" << (unsigned int)cal.monthday
+	   << " (" << cal.yearday << ") " << (unsigned int)cal.hour << ":"
+	   << (unsigned int)cal.minute << ":" << (unsigned int)cal.second;
 	return ss.str();
 }
 bool IsEqual(const calendar &expected, const calendar &actual) {
@@ -354,11 +354,11 @@ TEST(leapsec, tableSelect) {
 
 	pt1 = leapsec_get_table(0);
 	pt2 = leapsec_get_table(0);
-	TEST_ASSERT_EQUAL(pt1, pt2);
+	TEST_ASSERT_POINTERS_EQUAL(pt1, pt2);
 
 	pt1 = leapsec_get_table(1);
 	pt2 = leapsec_get_table(1);
-	TEST_ASSERT_EQUAL(pt1, pt2);
+	TEST_ASSERT_POINTERS_EQUAL(pt1, pt2);
 
 	pt1 = leapsec_get_table(1);
 	pt2 = leapsec_get_table(0);
@@ -371,14 +371,14 @@ TEST(leapsec, tableSelect) {
 	leapsec_set_table(pt1);
 	pt2 = leapsec_get_table(0);
 	pt3 = leapsec_get_table(1);
-	TEST_ASSERT_EQUAL(pt1, pt2);
+	TEST_ASSERT_POINTERS_EQUAL(pt1, pt2);
 	TEST_ASSERT_NOT_EQUAL(pt2, pt3);
 
 	pt1 = pt3;
 	leapsec_set_table(pt1);
 	pt2 = leapsec_get_table(0);
 	pt3 = leapsec_get_table(1);
-	TEST_ASSERT_EQUAL(pt1, pt2);
+	TEST_ASSERT_POINTERS_EQUAL(pt1, pt2);
 	TEST_ASSERT_NOT_EQUAL(pt2, pt3);
 }
 
@@ -577,14 +577,14 @@ TEST(leapsec, addDynamic) {
 	bool           rc;
 	int            idx;
 
-	static const uint32_t insns[] = {
-		2982009600u,	//	29	# 1 Jul 1994
-		3029443200u,	//	30	# 1 Jan 1996
-		3076704000u,	//	31	# 1 Jul 1997
-		3124137600u,	//	32	# 1 Jan 1999
-		3345062400u,	//	33	# 1 Jan 2006
-		3439756800u,	//	34	# 1 Jan 2009
-		3550089600u,	//	35	# 1 Jul 2012
+	static const time_t insns[] = {
+		2982009600,	//	29	# 1 Jul 1994
+		3029443200,	//	30	# 1 Jan 1996
+		3076704000,	//	31	# 1 Jul 1997
+		3124137600,	//	32	# 1 Jan 1999
+		3345062400,	//	33	# 1 Jan 2006
+		3439756800,	//	34	# 1 Jan 2009
+		3550089600,	//	35	# 1 Jul 2012
 		0 // sentinel
 	};
 
@@ -592,11 +592,14 @@ TEST(leapsec, addDynamic) {
 	TEST_ASSERT_TRUE(rc);
 
 	for (idx=1; insns[idx]; ++idx) {
-	    rc = leapsec_add_dyn(true, insns[idx]-JAN_1970 - 20*SECSPERDAY - 100);
+	    rc = leapsec_add_dyn(true,
+                                 insns[idx] - (time_t)JAN_1970 -
+                                 20*SECSPERDAY - 100);
 	    TEST_ASSERT_TRUE(rc);
 	}
 	// try to slip in a previous entry
-	rc = leapsec_add_dyn(true, insns[0]-JAN_1970 - 20*SECSPERDAY - 100);
+	rc = leapsec_add_dyn(true, insns[0] - (time_t)JAN_1970 -
+                             20*SECSPERDAY - 100);
 	TEST_ASSERT_FALSE(rc);
 	//leapsec_dump(pt, (leapsec_dumper)fprintf, stdout);
 	pt = leapsec_get_table(0);
@@ -607,16 +610,16 @@ TEST(leapsec, addDynamic) {
 // add fixed leap seconds (like from network packet)
 TEST(leapsec, addFixed) {
 	bool           rc;
-    int            idx;
+	int            idx;
 
-	static const struct { uint32_t tt; int of; } insns[] = {
-		{2982009600u-JAN_1970, 29},//	# 1 Jul 1994
-		{3029443200u-JAN_1970, 30},//	# 1 Jan 1996
-		{3076704000u-JAN_1970, 31},//	# 1 Jul 1997
-		{3124137600u-JAN_1970, 32},//	# 1 Jan 1999
-		{3345062400u-JAN_1970, 33},//	# 1 Jan 2006
-		{3439756800u-JAN_1970, 34},//	# 1 Jan 2009
-		{3550089600u-JAN_1970, 35},//	# 1 Jul 2012
+	static const struct { time_t tt; int of; } insns[] = {
+		{2982009600-JAN_1970, 29},//	# 1 Jul 1994
+		{3029443200-JAN_1970, 30},//	# 1 Jan 1996
+		{3076704000-JAN_1970, 31},//	# 1 Jul 1997
+		{3124137600-JAN_1970, 32},//	# 1 Jan 1999
+		{3345062400-JAN_1970, 33},//	# 1 Jan 2006
+		{3439756800-JAN_1970, 34},//	# 1 Jan 2009
+		{3550089600-JAN_1970, 35},//	# 1 Jul 2012
 		{0,0} // sentinel
 	};
 
@@ -629,7 +632,11 @@ TEST(leapsec, addFixed) {
 		insns[idx].of,
 		insns[idx].tt - 20*SECSPERDAY - 100,
 		insns[idx].tt + SECSPERDAY);
+#ifdef ENABLE_LEAP_TESTING
+		TEST_ASSERT_TRUE(rc);
+#else
 		TEST_ASSERT_FALSE(rc);
+#endif
 	}
 	// no do it right
 	for (idx=0; insns[idx].tt; ++idx) {
@@ -637,7 +644,11 @@ TEST(leapsec, addFixed) {
 		    insns[idx].of,
 		    insns[idx].tt,
 		    insns[idx].tt + SECSPERDAY);
+#ifdef ENABLE_LEAP_TESTING
+		TEST_ASSERT_FALSE(rc);
+#else
 		TEST_ASSERT_TRUE(rc);
+#endif
 	}
 	// try to slip in a previous entry
 	rc = leapsec_add_fix(
@@ -703,7 +714,7 @@ TEST(leapsec, ls2009seqInsDumb) {
 
 	rc = setup_load_table(leap1);
 	TEST_ASSERT_TRUE(rc);
-	TEST_ASSERT_EQUAL(0, leapsec_electric(-1));
+	TEST_ASSERT_FALSE(leapsec_electric(-1));
 
 	rc = leapsec_query(&qr, lsec2009 - 60*SECSPERDAY);
 	TEST_ASSERT_FALSE(rc);
@@ -794,7 +805,7 @@ TEST(leapsec, ls2009seqDelDumb) {
 
 	rc = setup_load_table(leap3);
 	TEST_ASSERT_TRUE(rc);
-	TEST_ASSERT_EQUAL(0, leapsec_electric(-1));
+	TEST_ASSERT_FALSE(leapsec_electric(-1));
 
 	rc = leapsec_query(&qr, lsec2009 - 60*SECSPERDAY);
 	TEST_ASSERT_FALSE(rc);
@@ -879,7 +890,7 @@ TEST(leapsec, ls2012seqInsDumb) {
 
 	rc = setup_load_table(leap1);
 	TEST_ASSERT_TRUE(rc);
-	TEST_ASSERT_EQUAL(0, leapsec_electric(-1));
+	TEST_ASSERT_FALSE(leapsec_electric(-1));
 
 	rc = leapsec_query(&qr, lsec2012 - 60*SECSPERDAY);
 	TEST_ASSERT_FALSE(rc);
@@ -925,11 +936,11 @@ TEST(leapsec, ls2012seqInsDumb) {
 TEST(leapsec, lsEmptyTableDumb) {
 	bool           rc;
 	leap_result_t  qr;
-	uint32_t       t;
-	const uint32_t t0   = lsec2012 - 10;
-	const uint32_t tE   = lsec2012 + 10;
+	time_t       t;
+	const time_t t0   = lsec2012 - 10;
+	const time_t tE   = lsec2012 + 10;
 
-	TEST_ASSERT_EQUAL(0, leapsec_electric(-1));
+	TEST_ASSERT_FALSE(leapsec_electric(-1));
 
 	for (t = t0; t != tE; ++t) {
 		rc = leapsec_query(&qr, t);
@@ -947,7 +958,7 @@ TEST(leapsec, lsEmptyTableElectric) {
 	time_t       t;
 
 	leapsec_electric(electric_on);
-	TEST_ASSERT_EQUAL(electric_on, leapsec_electric(electric_query));
+	TEST_ASSERT(electric_on == leapsec_electric(electric_query));
 
 	const time_t   t0 = lsec2012 - 10;
 	const time_t   tE = lsec2012 + 10;
