@@ -2,15 +2,16 @@ def options_cmd(ctx, config):
     ctx.load("compiler_c")
     ctx.load("msvc")
     ctx.load('waf_unit_test')
+    ctx.load('gnu_dirs')
 
     def callback_flags(option, opt, value, parser):
         config["OPT_STORE"].setdefault(opt, []).append(value)
 
     grp = ctx.add_option_group("NTP configure options")
     grp.add_option('--enable-debug', action='store_true',
-                   default=False, help="(ignored)")
+                   default=False, help="Enable debugging code")
     grp.add_option('--disable-debug', action='store_true',
-                   default=False, help="Disable debugging code")
+                   default=False, help="(ignored)")
     grp.add_option('--enable-debug-gdb', action='store_true',
                    default=False, help="Enable GDB debugging symbols")
     grp.add_option('--disable-droproot', action='store_true',
@@ -49,7 +50,8 @@ def options_cmd(ctx, config):
     grp.add_option('--enable-leap-smear', action='store_true',
                    default=False, help="Enable Leap Smearing.")
     grp.add_option('--enable-leap-testing', action='store_true',
-                   default=False, help="Enable leaps on other than 1st of month.")
+                   default=False,
+                   help="Enable leaps on other than 1st of month.")
     grp.add_option('--enable-mssntp', action='store_true',
                    default=False, help="Enable Samba MS SNTP support.")
     grp.add_option('--enable-lockclock', action='store_true',
@@ -69,15 +71,17 @@ def options_cmd(ctx, config):
     grp.add_option('--cflags', type='string', action="callback",
                    callback=callback_flags,
                    help="Users should use CFLAGS in their environment.")
+    grp.add_option('--build-epoch', type='int', default=None,
+                   help="Force epoch, or use SOURCE_DATE_EPOCH in environment")
     grp.add_option('--ldflags', type='string', action="callback",
                    callback=callback_flags,
                    help="Users should use LDFLAGS in their environment.")
-    grp.add_option('--fortify-flags', type='string', action='store',
-                   help="Fortify flags.")
     grp.add_option('--check', action='store_true', default=False,
                    help="Run tests")
     grp.add_option('--enable-rtems-trace', action='store_true',
                    default=False, help="Enable RTEMS Trace.")
+    grp.add_option('--enable-warnings', action='store_true',
+                   default=False, help="Enable annoying CC warnings")
     grp.add_option('--rtems-trace-path', type='string', default="",
                    help="Path to rtems-tld.")
     grp.add_option(
@@ -87,8 +91,6 @@ def options_cmd(ctx, config):
     grp.add_option('--undefine', type='string', action="callback",
                    callback=callback_flags,
                    help="Force undefinition of symbol.")
-    grp.add_option('--sbindir', type='string', action='store',
-                   default=None, help="Force ntpd installation directory.")
 
     grp = ctx.add_option_group("NTP documentation configure options")
     grp.add_option('--enable-doc', action='store_true',
@@ -98,7 +100,3 @@ def options_cmd(ctx, config):
                    help="Build NTP documentation with a2x XML lint")
     grp.add_option('--disable-manpage', action='store_true',
                    default=False, help="Disable Manpage building.")
-    grp.add_option('--htmldir', type='string', action='store',
-                   default=None, help="Force HTML installation directory.")
-    grp.add_option('--mandir', type='string', action='store',
-                   default=None, help="Force man page installation directory.")
