@@ -1,6 +1,5 @@
 from waflib.Configure import conf
 from waflib.TaskGen import feature, before_method
-import os
 
 
 @before_method('apply_incpaths')
@@ -17,20 +16,6 @@ def insert_srcdir(self):
         self.includes += ["%s/include" % srcnode]
 
 
-@before_method('apply_incpaths')
-@feature('libisc_include')
-def insert_libiscdir(self):
-        srcnode = self.bld.srcnode.abspath()
-        self.includes += ["%s/libisc/include/" % srcnode]
-
-
-@before_method('apply_incpaths')
-@feature('libisc_pthread_include')
-def insert_libiscpthreaddir(self):
-        srcnode = self.bld.srcnode.abspath()
-        self.includes += ["%s/libisc/pthreads/include/" % srcnode]
-
-
 def manpage_subst_fun(task, text):
         return text.replace("include::../docs/", "include::../../../docs/")
 
@@ -38,16 +23,7 @@ def manpage_subst_fun(task, text):
 @conf
 def manpage(ctx, section, source):
 
-        if ctx.env.MANDIR:
-                manprefix = ctx.env.MANDIR
-        elif os.path.isdir("/usr/man"):
-                manprefix = "/usr/man"
-        else:
-                manprefix = "/usr/share/man"
-        if not manprefix.endswith("/"):
-                manprefix += "/"
-
-        # ctx.install_files(manprefix + "man%s/" % section,
+        # ctx.install_files('${MANDIR}' + "/man%s/" % section,
         #                   source.replace("-man.txt", ".%s" % section))
 
         if not ctx.env.ENABLE_DOC or ctx.env.DISABLE_MANPAGE:
